package TaxSb

import (
	"context"
	"fmt"
	"git.listensoft.net/tool/jspkit/common"
	"git.listensoft.net/tool/jspkit/common/models"
	"git.listensoft.net/tool/jspkit/common/models/sb"
	"git.listensoft.net/tool/jspkit/common/variable"
	"git.listensoft.net/tool/jspkit/taxerr"
	"github.com/go-rod/rod"
	"github.com/go-rod/rod/lib/utils"
	"strings"
)

// SbXqyCwbb 小企业会计制度2013申报 标签页自动关闭
func SbXqyCwbb(ctx context.Context, newp1 *rod.Page, info models.CompanyInfo, task *models.TaxTask) {
	defer newp1.MustClose()
	// 数据获取
	kjzcfz := []sb.KjZcfz{}
	if ok := common.GetData(variable.KjZcfz, task.Data, &kjzcfz); !ok {
		task.Result.BusinessLog = "<span>[错误]:资产负债表数据为空</span><br />[操作]:请重新取数后重试"
		task.Result.BusinessStatus = variable.TaxFail
		return
	}
	kjlrb := []sb.KjLrb{}
	if ok := common.GetData(variable.KjLrb, task.Data, &kjlrb); !ok {
		task.Result.BusinessLog = "<span>[错误]:利润表数据为空</span><br />[操作]:请重新取数后重试"
		task.Result.BusinessStatus = variable.TaxFail
		return
	}
	kjxjllb := []sb.KjXjllb{}
	common.GetData(variable.KjXjllbJb, task.Data, &kjxjllb)
	err := rod.Try(func() {

		utils.Sleep(5)
		if newp1.MustHasX(`//div[contains(text(),'请重新选择报送所属期间或者去备案')]`) {
			task.Result.BusinessStatus = variable.TaxNoNeed
			task.Result.BusinessLog = "当前报送所属期间没有有效的备案信息"
			task.Result.BusinessImg = SaveErrImg(newp1, info)
			return
		}
		//全部改为直接申报 不区分上期是否已申报
		if newp1.MustHasX(`//div[text()='您上一期的财务报表未报送，请核实是否修改报送所属期。']`) {
			newp1.Timeout(common.ClickTimeOut).MustElementX(`//div[text()='您上一期的财务报表未报送，请核实是否修改报送所属期。']/..//button`).MustClick()
		}
		if newp1.Timeout(common.ClickTimeOut).MustHasX(`//span[contains(text(), "继续办理")]`) {
			newp1.Timeout(common.ClickTimeOut).MustElementX(`//span[contains(text(), "继续办理")]`).MustClick()
		}
		if newp1.MustHasR(`body > section > section > section > main > div > div > div > div.gov-inspect > div.gov-inspect-header > div.gov-inspect-header__status-text`, "检测不通过") {
			errMsg := newp1.Timeout(common.ClickTimeOut).MustElement(`body > section > section > section > main > div > div > div > div.gov-inspect > div.gov-inspect-table > div > div > div > div > span.gov-inspect-item__text > span`).MustText()
			task.Result.BusinessStatus = variable.TaxFail
			task.Result.BusinessImg = SaveErrImg(newp1, info)
			panic(taxerr.NewUserV3(errMsg, "请核实后重试"))
		}
		//检测不通过 返回首页
		if newp1.Timeout(common.ClickTimeOut).MustHasX(`//span[contains(text(), "返回首页")]`) {
			newp1.MustClose()
			task.Result.BusinessStatus = variable.TaxFail
			task.Result.BusinessLog = "检测不通过"
			task.Result.BusinessImg = SaveErrImg(newp1, info)
			return
		}
		//提示
		if newp1.MustHasX(`//div[@class="t-dialog__body t-dialog__body--icon"]`) {
			newp1.Timeout(common.ClickTimeOut).MustElementX(`//span[text()="关闭"]`).MustClick()
		}
		utils.Sleep(3)
		if newp1.MustHasX(`//div[@class="t-dialog__body t-dialog__body__icon"]`) {
			text := newp1.MustElementX(`//div[@class="t-dialog__body t-dialog__body__icon"]`).MustText()
			if strings.Contains(text, "未报送") {
				panic(taxerr.NewUserV3(text, "如需申报请联系客服"))
			}
		}
		// 选择在线填写
		if newp1.Timeout(common.ClickTimeOut).MustHas(`#page-content > div > section > main > div > div > div > div.content-body > div > div:nth-child(3) > div`) {
			newp1.Timeout(common.ClickTimeOut).MustElement(`#page-content > div > section > main > div > div > div > div.content-body > div > div:nth-child(3) > div`).MustClick()
		}
		utils.Sleep(1)
		rr := newp1.MustWaitRequestIdle()
		newp1.Timeout(common.ClickTimeOut).MustSearch(`下一步`).MustClick()
		rr()
		utils.Sleep(3)
		//"该所属期已完成申报，是否要进行该所属期的申报错误更正"
		if newp1.MustHasX(`//div[@class="t-dialog__body t-dialog__body__icon"]`) {
			task.Result.BusinessStatus = variable.TaxSuccess
			return
		}
		xqycwbbDeclareDo(ctx, newp1, info, kjzcfz, kjlrb, kjxjllb, task)
	})
	if err != nil {
		task.Result.BusinessStatus = variable.TaxFail
		task.Result.BusinessLog = common.HandleError(ctx, err).Error()
		return
	}
	return
}

// 小企业会计制度2013填表
func xqycwbbDeclareDo(ctx context.Context, newp1 *rod.Page, info models.CompanyInfo, kjzcfz []sb.KjZcfz, kjlrb []sb.KjLrb, kjxjllb []sb.KjXjllb, task *models.TaxTask) {
	err := rod.Try(func() {
		zz := WaitElementXZcFz(newp1, `//h1[contains(text(),'资产负债表')]`, 1).MustText()
		if len(zz) == 0 {
			panic(taxerr.NewUserV3(`网页卡顿`, "请稍后重试"))
		}
		if !strings.Contains(zz, "小企业") {
			path := SaveErrImg(newp1, info)
			task.Result.BusinessImg = path
			panic(taxerr.NewUserV3(`会计准则选择错误`, "请修改后重试"))
		}
		newp2 := newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame()
		//资产负债表
		newp2.Timeout(common.ClickTimeOut).MustElement(`#divSheetlist > li:nth-child(1) > a`).MustClick()
		utils.Sleep(2)
		//if newp.Timeout(common.ClickTimeOut).MustHasR(`#viewCtrlId > div.NewTableHead > h1`, "企业会计制度") {
		//	panic(taxerr.NewUserV3(`会计准则选择错误，税局为(企业会计制度)`))
		//}
		//*** 校验
		// 年初余额
		ncFlag := false
		//newp := newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame()
		if kjzcfz[len(kjzcfz)-1].NcyeZc != 0 && kjzcfz[len(kjzcfz)-1].NcyeQy != 0 {
			ncFlag = true
			common.Input(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"货币资金")]/..//input)[2]`, common.FloatToStr(kjzcfz[0].NcyeZc))
			common.Input(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"短期投资")]/..//input)[2]`, common.FloatToStr(kjzcfz[1].NcyeZc))
			common.Input(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"应收票据")]/..//input)[2]`, common.FloatToStr(kjzcfz[2].NcyeZc))
			common.Input(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"应收账款")]/..//input)[2]`, common.FloatToStr(kjzcfz[3].NcyeZc))
			common.Input(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"预付账款")]/..//input)[2]`, common.FloatToStr(kjzcfz[4].NcyeZc))
			common.Input(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"应收股利")]/..//input)[2]`, common.FloatToStr(kjzcfz[5].NcyeZc))
			common.Input(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"应收利息")]/..//input)[2]`, common.FloatToStr(kjzcfz[6].NcyeZc))
			common.Input(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"其他应收款")]/..//input)[2]`, common.FloatToStr(kjzcfz[7].NcyeZc))
			common.Input(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"存货")]/..//input)[2]`, common.FloatToStr(kjzcfz[8].NcyeZc))
			common.Input(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"其中：原材料")]/..//input)[2]`, common.FloatToStr(kjzcfz[9].NcyeZc))
			common.Input(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"在产品")]/..//input)[2]`, common.FloatToStr(kjzcfz[10].NcyeZc))
			common.Input(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"库存商品")]/..//input)[2]`, common.FloatToStr(kjzcfz[11].NcyeZc))
			common.Input(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"周转材料")]/..//input)[2]`, common.FloatToStr(kjzcfz[12].NcyeZc))
			common.Input(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"其他流动资产")]/..//input)[2]`, common.FloatToStr(kjzcfz[13].NcyeZc))
			common.Input(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"长期债券投资")]/..//input)[2]`, common.FloatToStr(kjzcfz[16].NcyeZc))
			common.Input(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"长期股权投资")]/..//input)[2]`, common.FloatToStr(kjzcfz[17].NcyeZc))
			common.Input(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"固定资产原价")]/..//input)[2]`, common.FloatToStr(kjzcfz[18].NcyeZc))
			common.Input(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"减：累计折旧")]/..//input)[2]`, common.FloatToStr(kjzcfz[19].NcyeZc))
			common.Input(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"在建工程")]/..//input)[2]`, common.FloatToStr(kjzcfz[21].NcyeZc))
			common.Input(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"工程物资")]/..//input)[2]`, common.FloatToStr(kjzcfz[22].NcyeZc))
			common.Input(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"固定资产清理")]/..//input)[2]`, common.FloatToStr(kjzcfz[23].NcyeZc))
			common.Input(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"生产性生物资产")]/..//input)[2]`, common.FloatToStr(kjzcfz[24].NcyeZc))
			common.Input(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"无形资产")]/..//input)[2]`, common.FloatToStr(kjzcfz[25].NcyeZc))
			common.Input(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"开发支出")]/..//input)[2]`, common.FloatToStr(kjzcfz[26].NcyeZc))
			common.Input(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"长期待摊费用")]/..//input)[2]`, common.FloatToStr(kjzcfz[27].NcyeZc))
			common.Input(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"其他非流动资产")]/..//input)[2]`, common.FloatToStr(kjzcfz[28].NcyeZc))
			common.Input(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"短期借款")]/..//input)[4]`, common.FloatToStr(kjzcfz[0].NcyeQy))
			common.Input(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"应付票据")]/..//input)[4]`, common.FloatToStr(kjzcfz[1].NcyeQy))
			common.Input(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"应付账款")]/..//input)[4]`, common.FloatToStr(kjzcfz[2].NcyeQy))
			common.Input(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"预收账款")]/..//input)[4]`, common.FloatToStr(kjzcfz[3].NcyeQy))
			common.Input(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"应付职工薪酬")]/..//input)[4]`, common.FloatToStr(kjzcfz[4].NcyeQy))
			common.Input(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"应交税费")]/..//input)[4]`, common.FloatToStr(kjzcfz[5].NcyeQy))
			common.Input(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"应付利息")]/..//input)[4]`, common.FloatToStr(kjzcfz[6].NcyeQy))
			common.Input(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"应付利润")]/..//input)[4]`, common.FloatToStr(kjzcfz[7].NcyeQy))
			common.Input(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"其他应付款")]/..//input)[4]`, common.FloatToStr(kjzcfz[8].NcyeQy))
			common.Input(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"其他流动负债")]/..//input)[4]`, common.FloatToStr(kjzcfz[9].NcyeQy))
			common.Input(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"长期借款")]/..//input)[4]`, common.FloatToStr(kjzcfz[12].NcyeQy))
			common.Input(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"长期应付款")]/..//input)[4]`, common.FloatToStr(kjzcfz[13].NcyeQy))
			common.Input(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"递延收益")]/..//input)[4]`, common.FloatToStr(kjzcfz[14].NcyeQy))
			common.Input(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"其他非流动负债")]/..//input)[4]`, common.FloatToStr(kjzcfz[15].NcyeQy))
			common.Input(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"实收资本（或股本）")]/..//input)[4]`, common.FloatToStr(kjzcfz[25].NcyeQy))
			common.Input(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"资本公积")]/..//input)[4]`, common.FloatToStr(kjzcfz[26].NcyeQy))
			common.Input(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"盈余公积")]/..//input)[4]`, common.FloatToStr(kjzcfz[27].NcyeQy))
			common.Input(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"未分配利润")]/..//input)[4]`, common.FloatToStr(kjzcfz[28].NcyeQy))
		}
		// 流动资产合计校验//context.deadlineExceededError
		ncyeZc := newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame().MustEval(`()=>{return document.evaluate('//input[@ng-model="syxqyzcfzbGrid.xqyzcfzbGridlb[14].ncyeZc"]', document, null, XPathResult.FIRST_ORDERED_NODE_TYPE, null).singleNodeValue.value}`).Str()
		ncyeZc = strings.ReplaceAll(ncyeZc, ",", "")
		if ncFlag && kjzcfz[14].NcyeZc != common.StrToFloat(ncyeZc) {
			panic(taxerr.NewUserV3(`年初余额流动资产合计与系统不一致，系统为：`+common.FloatToStr(kjzcfz[14].NcyeZc)+`，税局为：`+ncyeZc, "请核实后重试"))
		}
		//货币资金
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `//input[@ng-model="syxqyzcfzbGrid.xqyzcfzbGridlb[0].qmyeZc"]`, common.FloatToStr(kjzcfz[0].QmyeZc))
		//短期投资
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `//input[@ng-model="syxqyzcfzbGrid.xqyzcfzbGridlb[1].qmyeZc"]`, common.FloatToStr(kjzcfz[1].QmyeZc))
		//应收票据
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"应收票据")]/..//input)[1]`, common.FloatToStr(kjzcfz[2].QmyeZc))
		//应收账款
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"应收账款")]/..//input)[1]`, common.FloatToStr(kjzcfz[3].QmyeZc))
		//预付账款
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"预付账款")]/..//input)[1]`, common.FloatToStr(kjzcfz[4].QmyeZc))
		//应收股利
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"应收股利")]/..//input)[1]`, common.FloatToStr(kjzcfz[5].QmyeZc))
		//应收利息
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"应收利息")]/..//input)[1]`, common.FloatToStr(kjzcfz[6].QmyeZc))
		//其他应收款
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"其他应收款")]/..//input)[1]`, common.FloatToStr(kjzcfz[7].QmyeZc))
		//存货
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"存货")]/..//input)[1]`, common.FloatToStr(kjzcfz[8].QmyeZc))
		//其中 ：原材料
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"其中：原材料")]/..//input)[1]`, common.FloatToStr(kjzcfz[9].QmyeZc))
		//在产品
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"在产品")]/..//input)[1]`, common.FloatToStr(kjzcfz[10].QmyeZc))
		//库存商品
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"库存商品")]/..//input)[1]`, common.FloatToStr(kjzcfz[11].QmyeZc))
		//周转材料
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"周转材料")]/..//input)[1]`, common.FloatToStr(kjzcfz[12].QmyeZc))
		//其他流动资产
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"其他流动资产")]/..//input)[1]`, common.FloatToStr(kjzcfz[13].QmyeZc))
		//流动资产合计
		//common.Input(newp, `#\30 01C15`, common.FloatToStr(kjzcfz[14].QmyeZc))
		//common.Input(newp, `#\30 01D15`, common.FloatToStr(kjzcfz[14].NcyeZc))
		//非流动资产
		//长期债券投资
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"长期债券投资")]/..//input)[1]`, common.FloatToStr(kjzcfz[16].QmyeZc))
		//长期股权投资
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"长期股权投资")]/..//input)[1]`, common.FloatToStr(kjzcfz[17].QmyeZc))
		//固定资产原价
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"固定资产原价")]/..//input)[1]`, common.FloatToStr(kjzcfz[18].QmyeZc))
		//减：累计折旧
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"减：累计折旧")]/..//input)[1]`, common.FloatToStr(kjzcfz[19].QmyeZc))
		//固定资产账面价值
		//common.Input(newp, `#\30 01C20`, common.FloatToStr(kjzcfz[20].QmyeZc))
		//common.Input(newp, `#\30 01D20`, common.FloatToStr(kjzcfz[20].NcyeZc))
		//在建工程
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"在建工程")]/..//input)[1]`, common.FloatToStr(kjzcfz[21].QmyeZc))
		//工程物资
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"工程物资")]/..//input)[1]`, common.FloatToStr(kjzcfz[22].QmyeZc))
		//固定资产清理
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"固定资产清理")]/..//input)[1]`, common.FloatToStr(kjzcfz[23].QmyeZc))
		//生物性生物资产
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"生产性生物资产")]/..//input)[1]`, common.FloatToStr(kjzcfz[24].QmyeZc))
		//无形资产
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"无形资产")]/..//input)[1]`, common.FloatToStr(kjzcfz[25].QmyeZc))
		//开发支出
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"开发支出")]/..//input)[1]`, common.FloatToStr(kjzcfz[26].QmyeZc))
		//长期待摊费用
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"长期待摊费用")]/..//input)[1]`, common.FloatToStr(kjzcfz[27].QmyeZc))
		//其他非流动资产
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"其他非流动资产")]/..//input)[1]`, common.FloatToStr(kjzcfz[28].QmyeZc))
		//非流动资产合计
		//common.Input(newp, `#\30 01C29`, common.FloatToStr(kjzcfz[29].QmyeZc))
		//common.Input(newp, `#\30 01D29`, common.FloatToStr(kjzcfz[29].NcyeZc))
		////资产合计
		//common.Input(newp, `#\30 01C30`, common.FloatToStr(kjzcfz[30].QmyeZc))
		//common.Input(newp, `#\30 01D30`, common.FloatToStr(kjzcfz[30].NcyeZc))

		//流动负债
		//短期借款
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"短期借款")]/..//input)[3]`, common.FloatToStr(kjzcfz[0].QmyeQy))
		//应付票据
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"应付票据")]/..//input)[3]`, common.FloatToStr(kjzcfz[1].QmyeQy))
		//应付账款
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"应付账款")]/..//input)[3]`, common.FloatToStr(kjzcfz[2].QmyeQy))
		//预收账款
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"预收账款")]/..//input)[3]`, common.FloatToStr(kjzcfz[3].QmyeQy))
		//应付职工薪酬
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"应付职工薪酬")]/..//input)[3]`, common.FloatToStr(kjzcfz[4].QmyeQy))
		//应交税费
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"应交税费")]/..//input)[3]`, common.FloatToStr(kjzcfz[5].QmyeQy))
		//应付利息
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"应付利息")]/..//input)[3]`, common.FloatToStr(kjzcfz[6].QmyeQy))
		//应付利润
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"应付利润")]/..//input)[3]`, common.FloatToStr(kjzcfz[7].QmyeQy))
		//其他应付款
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"其他应付款")]/..//input)[3]`, common.FloatToStr(kjzcfz[8].QmyeQy))
		//其他流动负债
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"其他流动负债")]/..//input)[3]`, common.FloatToStr(kjzcfz[9].QmyeQy))
		//非流动负债
		//长期借款
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"长期借款")]/..//input)[3]`, common.FloatToStr(kjzcfz[12].QmyeQy))
		//长期应付款
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"长期应付款")]/..//input)[3]`, common.FloatToStr(kjzcfz[13].QmyeQy))
		//递延收益
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"递延收益")]/..//input)[3]`, common.FloatToStr(kjzcfz[14].QmyeQy))
		//其他非流动负债
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"其他非流动负债")]/..//input)[3]`, common.FloatToStr(kjzcfz[15].QmyeQy))
		//实收资本（或股份）
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"实收资本（或股本）")]/..//input)[3]`, common.FloatToStr(kjzcfz[25].QmyeQy))
		//资本公积
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"资本公积")]/..//input)[3]`, common.FloatToStr(kjzcfz[26].QmyeQy))
		//盈余公积
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"盈余公积")]/..//input)[3]`, common.FloatToStr(kjzcfz[27].QmyeQy))
		//未分配利润
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"未分配利润")]/..//input)[3]`, common.FloatToStr(kjzcfz[28].QmyeQy))
		//这里需要失去焦距，不然不会计算
		newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame().MustElementX(`(//td[contains(text(),"盈余公积")]/..//input)[3]`).MustClick()
		utils.Sleep(0.5)
		//所有者权益（或股东权益）合计
		// 非流动资产合计校验
		ncyeZc2 := newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame().
			MustEval(`()=>{return document.evaluate('//input[@ng-model="syxqyzcfzbGrid.xqyzcfzbGridlb[29].ncyeZc"]', document, null, XPathResult.FIRST_ORDERED_NODE_TYPE, null).singleNodeValue.value}`).Str()
		ncyeZc2 = strings.ReplaceAll(ncyeZc2, ",", "")
		//ncyeZc2 := *newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame().MustElementX(`(//td[contains(text(),"非流动资产合计")]/..//input)[2]`).MustAttribute("value")
		if ncFlag && kjzcfz[29].NcyeZc != common.StrToFloat(ncyeZc2) {
			panic(taxerr.NewUserV3(`年初余额非流动资产合计与系统不一致，系统为：`+common.FloatToStr(kjzcfz[29].NcyeZc)+`，税局为：`+ncyeZc2, "请核实后重试"))
		}
		// 资产合计校验
		ncyeZc3 := newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame().
			MustEval(`()=>{return document.evaluate('//input[@ng-model="syxqyzcfzbGrid.xqyzcfzbGridlb[30].ncyeZc"]', document, null, XPathResult.FIRST_ORDERED_NODE_TYPE, null).singleNodeValue.value}`).Str()
		ncyeZc3 = strings.ReplaceAll(ncyeZc3, ",", "")
		//ncyeZc3 := *newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame().MustElementX(`(//td[contains(text(),"资产合计")]/..//input)[2]`).MustAttribute("value")
		if ncFlag && kjzcfz[30].NcyeZc != common.StrToFloat(ncyeZc3) {
			panic(taxerr.NewUserV3(`年初余额资产合计校验与系统不一致，系统为：`+common.FloatToStr(kjzcfz[30].NcyeZc)+`，税局为：`+ncyeZc3, "请核实后重试"))
		}
		ncyeZc4 := newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame().
			MustEval(`()=>{return document.evaluate('//input[@ng-model="syxqyzcfzbGrid.xqyzcfzbGridlb[10].ncyeQy"]', document, null, XPathResult.FIRST_ORDERED_NODE_TYPE, null).singleNodeValue.value}`).Str()
		ncyeZc4 = strings.ReplaceAll(ncyeZc4, ",", "")
		//ncyeZc4 := *newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame().MustElementX(`(//td[contains(text(),"流动负债合计")]/..//input)[4]`).MustAttribute("value")
		if ncFlag && kjzcfz[10].NcyeQy != common.StrToFloat(ncyeZc4) {
			panic(taxerr.NewUserV3(`年初余额流动负债合计与系统不一致，系统为：`+common.FloatToStr(kjzcfz[10].NcyeQy)+`，税局为：`+ncyeZc4, "请核实后重试"))
		}
		//非流动负债合计校验
		ncyeZc5 := newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame().
			MustEval(`()=>{return document.evaluate('//input[@ng-model="syxqyzcfzbGrid.xqyzcfzbGridlb[16].ncyeQy"]', document, null, XPathResult.FIRST_ORDERED_NODE_TYPE, null).singleNodeValue.value}`).Str()
		ncyeZc5 = strings.ReplaceAll(ncyeZc5, ",", "")
		//ncyeZc5 := *newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame().MustElementX(`(//td[contains(text(),"非流动负债合计")]/..//input)[4]`).MustAttribute("value")
		if ncFlag && kjzcfz[16].NcyeQy != common.StrToFloat(ncyeZc5) {
			panic(taxerr.NewUserV3(`年初余额非流动负债合计与系统不一致，系统为：`+common.FloatToStr(kjzcfz[16].NcyeQy)+`，税局为：`+ncyeZc5, "请核实后重试"))
		}
		//负债合计校验
		ncyeZc6 := newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame().
			MustEval(`()=>{return document.evaluate('//input[@ng-model="syxqyzcfzbGrid.xqyzcfzbGridlb[17].ncyeQy"]', document, null, XPathResult.FIRST_ORDERED_NODE_TYPE, null).singleNodeValue.value}`).Str()
		ncyeZc6 = strings.ReplaceAll(ncyeZc6, ",", "")
		//ncyeZc6 := *newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame().MustElementX(`(//td[contains(text(),"负债合计")]/..//input)[4]`).MustAttribute("value")
		if ncFlag && kjzcfz[17].NcyeQy != common.StrToFloat(ncyeZc6) {
			panic(taxerr.NewUserV3(`年初余额负债合计与系统不一致，系统为：`+common.FloatToStr(kjzcfz[17].NcyeQy)+`，税局为：`+ncyeZc6, "请核实后重试"))
		}
		//所有者权益(或股东权益)合计校验
		ncyeZc7 := newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame().
			MustEval(`()=>{return document.evaluate('//input[@ng-model="syxqyzcfzbGrid.xqyzcfzbGridlb[29].ncyeQy"]', document, null, XPathResult.FIRST_ORDERED_NODE_TYPE, null).singleNodeValue.value}`).Str()
		ncyeZc7 = strings.ReplaceAll(ncyeZc7, ",", "")
		//ncyeZc7 := *newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame().MustElementX(`(//td[contains(text(),"所有者权益（或股东权益）合计")]/..//input)[4]`).MustAttribute("value")
		if ncFlag && kjzcfz[29].NcyeQy != common.StrToFloat(ncyeZc7) {
			panic(taxerr.NewUserV3(`年初余额所有者权益(或股东权益)合计与系统不一致，系统为：`+common.FloatToStr(kjzcfz[29].NcyeQy)+`，税局为：`+ncyeZc7, "请核实后重试"))
		}
		////负债和所有者权益（或股东权益）总计
		//common.Input(newp, `#\30 01G30`, common.FloatToStr(kjzcfz[30].QmyeQy))
		//common.Input(newp, `#\30 01H30`, common.FloatToStr(kjzcfz[30].NcyeQy))
		//负债和所有者权益（或股东权益）总计校验
		ncyeZc8 := newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame().
			MustEval(`()=>{return document.evaluate('//input[@ng-model="syxqyzcfzbGrid.xqyzcfzbGridlb[30].ncyeQy"]', document, null, XPathResult.FIRST_ORDERED_NODE_TYPE, null).singleNodeValue.value}`).Str()
		ncyeZc8 = strings.ReplaceAll(ncyeZc8, ",", "")
		//ncyeZc8 := *newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame().MustElementX(`(//td[contains(text(),"所有者权益（或股东权益）合计")]/..//input)[4]`).MustAttribute("value")
		if kjzcfz[30].NcyeQy != common.StrToFloat(ncyeZc8) {
			panic(taxerr.NewUserV3(`年初余额负债和所有者权益（或股东权益）总计校验与系统不一致，系统为：`+common.FloatToStr(kjzcfz[30].NcyeQy)+`，税局为：`+ncyeZc8, "请核实后重试"))
		}
		//利润表
		rr := newp1.MustWaitRequestIdle()
		newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#divSheetlist > li:nth-child(2) > a`).MustClick() //点击利润表
		rr()
		lrb := WaitElementXZcFz(newp1, "//h1[contains(text(),'利润表')]", 1).MustText()
		if len(lrb) == 0 {
			panic(taxerr.NewUserV3("税局卡顿资产负债表加载异常", "请稍后重试"))
		}
		utils.Sleep(3)
		//营业收入
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"营业收入")]/..//input)[2]`, common.FloatToStr(kjlrb[0].PeriodTotal))
		utils.Sleep(0.5)
		//减：营业成本
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"减：营业成本")]/..//input)[2]`, common.FloatToStr(kjlrb[1].PeriodTotal))
		utils.Sleep(0.5)
		//税金及附加
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"税金及附加")]/..//input)[2]`, common.FloatToStr(kjlrb[2].PeriodTotal))
		utils.Sleep(0.5)
		//其中：消费税
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"其中：消费税")]/..//input)[2]`, common.FloatToStr(kjlrb[3].PeriodTotal))
		utils.Sleep(0.5)
		//营业税
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"营业税")]/..//input)[2]`, common.FloatToStr(kjlrb[4].PeriodTotal))
		utils.Sleep(0.5)
		//城市维护建设税
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"城市维护建设税")]/..//input)[2]`, common.FloatToStr(kjlrb[5].PeriodTotal))
		utils.Sleep(0.5)
		//资源税
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"资源税")]/..//input)[2]`, common.FloatToStr(kjlrb[6].PeriodTotal))
		utils.Sleep(0.5)
		//土地增值税
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"土地增值税")]/..//input)[2]`, common.FloatToStr(kjlrb[7].PeriodTotal))
		utils.Sleep(0.5)
		// 城镇土地使用税、房产税、车船税、印花税
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"城镇土地使用税、房产税、车船税、印花税")]/..//input)[2]`, common.FloatToStr(kjlrb[8].PeriodTotal))
		utils.Sleep(0.5)
		//教育费附加、矿产资源补偿费、排污费
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"教育费附加、矿产资源补偿费、排污费")]/..//input)[2]`, common.FloatToStr(kjlrb[9].PeriodTotal))
		utils.Sleep(0.5)
		//销售费用
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"销售费用")]/..//input)[2]`, common.FloatToStr(kjlrb[10].PeriodTotal))
		utils.Sleep(0.5)
		//其中：商品维修费
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"其中：商品维修费")]/..//input)[2]`, common.FloatToStr(kjlrb[11].PeriodTotal))
		utils.Sleep(0.5)
		//广告费和业务宣传费
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"广告费和业务宣传费")]/..//input)[2]`, common.FloatToStr(kjlrb[12].PeriodTotal))
		utils.Sleep(0.5)
		//管理费用
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"管理费用")]/..//input)[2]`, common.FloatToStr(kjlrb[13].PeriodTotal))
		utils.Sleep(0.5)
		//其中：开办费
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"其中：开办费")]/..//input)[2]`, common.FloatToStr(kjlrb[14].PeriodTotal))
		utils.Sleep(0.5)
		//业务招待费
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"业务招待费")]/..//input)[2]`, common.FloatToStr(kjlrb[15].PeriodTotal))
		utils.Sleep(0.5)
		//研究费用
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"研究费用")]/..//input)[2]`, common.FloatToStr(kjlrb[16].PeriodTotal))
		utils.Sleep(0.5)
		//财务费用
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"财务费用")]/..//input)[2]`, common.FloatToStr(kjlrb[17].PeriodTotal))
		utils.Sleep(0.5)
		//其中：利息费用
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"其中：利息费用（收入以－号填列）")]/..//input)[2]`, common.FloatToStr(kjlrb[18].PeriodTotal))
		utils.Sleep(0.5)
		//加：投资收益
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"加：投资收益（损失以－号填列）")]/..//input)[2]`, common.FloatToStr(kjlrb[19].PeriodTotal))
		utils.Sleep(0.5)
		//加：营业外收入
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"加：营业外收入")]/..//input)[2]`, common.FloatToStr(kjlrb[21].PeriodTotal))
		utils.Sleep(0.5)
		//其中：政府补助
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"其中：政府补助")]/..//input)[2]`, common.FloatToStr(kjlrb[22].PeriodTotal))
		utils.Sleep(0.5)
		//减：营业外支出
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"减：营业外支出")]/..//input)[2]`, common.FloatToStr(kjlrb[23].PeriodTotal))
		utils.Sleep(0.5)
		//其中：坏账损失//
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"其中：坏账损失")]/..//input)[2]`, common.FloatToStr(kjlrb[24].PeriodTotal))
		utils.Sleep(0.5)
		//无法收回的长期债券投资损失
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"无法收回的长期债券投资损失")]/..//input)[2]`, common.FloatToStr(kjlrb[25].PeriodTotal))
		utils.Sleep(0.5)
		//无法收回的长期股权投资损失
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"无法收回的长期股权投资损失")]/..//input)[2]`, common.FloatToStr(kjlrb[26].PeriodTotal))
		utils.Sleep(0.5)
		//自然灾害等不可抗力因素造成的损失
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"自然灾害等不可抗力因素造成的损失")]/..//input)[2]`, common.FloatToStr(kjlrb[27].PeriodTotal))
		utils.Sleep(0.5)
		//税收滞纳金
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"税收滞纳金")]/..//input)[2]`, common.FloatToStr(kjlrb[28].PeriodTotal))
		utils.Sleep(0.5)
		//   减：所得税费用
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"减：所得税费用")]/..//input)[2]`, common.FloatToStr(kjlrb[30].PeriodTotal))
		utils.Sleep(3)

		//本年数
		//营业收入
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"营业收入")]/..//input)[1]`, common.FloatToStr(kjlrb[0].YearTotal))
		utils.Sleep(0.5)
		//减：营业成本
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"减：营业成本")]/..//input)[1]`, common.FloatToStr(kjlrb[1].YearTotal))
		utils.Sleep(0.5)
		//税金及附加
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"税金及附加")]/..//input)[1]`, common.FloatToStr(kjlrb[2].YearTotal))
		utils.Sleep(0.5)
		//其中：消费税
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"其中：消费税")]/..//input)[1]`, common.FloatToStr(kjlrb[3].YearTotal))
		utils.Sleep(0.5)
		//营业税
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"营业税")]/..//input)[1]`, common.FloatToStr(kjlrb[4].YearTotal))
		utils.Sleep(0.5)
		//城市维护建设税
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"城市维护建设税")]/..//input)[1]`, common.FloatToStr(kjlrb[5].YearTotal))
		utils.Sleep(0.5)
		//资源税
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"资源税")]/..//input)[1]`, common.FloatToStr(kjlrb[6].YearTotal))
		utils.Sleep(0.5)
		//土地增值税
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"土地增值税")]/..//input)[1]`, common.FloatToStr(kjlrb[7].YearTotal))
		utils.Sleep(0.5)
		// 城镇土地使用税、房产税、车船税、印花税
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"城镇土地使用税、房产税、车船税、印花税")]/..//input)[1]`, common.FloatToStr(kjlrb[8].YearTotal))
		utils.Sleep(0.5)
		//教育费附加、矿产资源补偿费、排污费
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"教育费附加、矿产资源补偿费、排污费")]/..//input)[1]`, common.FloatToStr(kjlrb[9].YearTotal))
		utils.Sleep(0.5)
		//销售费用
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"销售费用")]/..//input)[1]`, common.FloatToStr(kjlrb[10].YearTotal))
		utils.Sleep(0.5)
		//其中：商品维修费
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"其中：商品维修费")]/..//input)[1]`, common.FloatToStr(kjlrb[11].YearTotal))
		utils.Sleep(0.5)
		//广告费和业务宣传费
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"广告费和业务宣传费")]/..//input)[1]`, common.FloatToStr(kjlrb[12].YearTotal))
		utils.Sleep(0.5)
		//管理费用
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"管理费用")]/..//input)[1]`, common.FloatToStr(kjlrb[13].YearTotal))
		utils.Sleep(0.5)
		//其中：开办费
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"其中：开办费")]/..//input)[1]`, common.FloatToStr(kjlrb[14].YearTotal))
		utils.Sleep(0.5)
		//业务招待费
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"业务招待费")]/..//input)[1]`, common.FloatToStr(kjlrb[15].YearTotal))
		utils.Sleep(0.5)
		//研究费用
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"研究费用")]/..//input)[1]`, common.FloatToStr(kjlrb[16].YearTotal))
		utils.Sleep(0.5)
		//财务费用
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"财务费用")]/..//input)[1]`, common.FloatToStr(kjlrb[17].YearTotal))
		utils.Sleep(0.5)
		//其中：利息费用
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"其中：利息费用（收入以－号填列）")]/..//input)[1]`, common.FloatToStr(kjlrb[18].YearTotal))
		utils.Sleep(0.5)
		//加：投资收益
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"加：投资收益（损失以－号填列）")]/..//input)[1]`, common.FloatToStr(kjlrb[19].YearTotal))
		utils.Sleep(0.5)
		//加：营业外收入
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"加：营业外收入")]/..//input)[1]`, common.FloatToStr(kjlrb[21].YearTotal))
		utils.Sleep(0.5)
		//其中：政府补助
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"其中：政府补助")]/..//input)[1]`, common.FloatToStr(kjlrb[22].YearTotal))
		utils.Sleep(0.5)
		//减：营业外支出
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"减：营业外支出")]/..//input)[1]`, common.FloatToStr(kjlrb[23].YearTotal))
		utils.Sleep(0.5)
		//其中：坏账损失//
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"其中：坏账损失")]/..//input)[1]`, common.FloatToStr(kjlrb[24].YearTotal))
		utils.Sleep(0.5)
		//无法收回的长期债券投资损失
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"无法收回的长期债券投资损失")]/..//input)[1]`, common.FloatToStr(kjlrb[25].YearTotal))
		utils.Sleep(0.5)
		//无法收回的长期股权投资损失
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"无法收回的长期股权投资损失")]/..//input)[1]`, common.FloatToStr(kjlrb[26].YearTotal))
		utils.Sleep(0.5)
		//自然灾害等不可抗力因素造成的损失
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"自然灾害等不可抗力因素造成的损失")]/..//input)[1]`, common.FloatToStr(kjlrb[27].YearTotal))
		utils.Sleep(0.5)
		//税收滞纳金
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"税收滞纳金")]/..//input)[1]`, common.FloatToStr(kjlrb[28].YearTotal))
		utils.Sleep(0.5)
		//   减：所得税费用
		common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"减：所得税费用")]/..//input)[1]`, common.FloatToStr(kjlrb[30].YearTotal))
		utils.Sleep(3)

		v1 := strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"一、营业收入")]/..//input)[1]`).MustText(), ",", "")
		v2 := strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"一、营业收入")]/..//input)[2]`).MustText(), ",", "")
		if kjlrb[0].YearTotal != common.StrToFloat(v1) || kjlrb[0].PeriodTotal != common.StrToFloat(v2) {
			panic(taxerr.NewUserV3(fmt.Sprintf("营业收入校验与系统不一致，系统为：年：%s，本期：%s，税局为：年：%s，本期：%s", common.FloatToStr(kjlrb[0].YearTotal), common.FloatToStr(kjlrb[0].PeriodTotal), v1, v2), "请核实后重试"))
		}
		v1 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"减：营业成本")]/..//input)[1]`).MustText(), ",", "")
		v2 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"减：营业成本")]/..//input)[2]`).MustText(), ",", "")
		if kjlrb[1].YearTotal != common.StrToFloat(v1) || kjlrb[1].PeriodTotal != common.StrToFloat(v2) {
			panic(taxerr.NewUserV3(fmt.Sprintf("减：营业成本校验与系统不一致，系统为：年：%s，本期：%s，税局为：年：%s，本期：%s", common.FloatToStr(kjlrb[1].YearTotal), common.FloatToStr(kjlrb[1].PeriodTotal), v1, v2), "请核实后重试"))
		}
		v1 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"税金及附加")]/..//input)[1]`).MustText(), ",", "")
		v2 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"税金及附加")]/..//input)[2]`).MustText(), ",", "")
		if kjlrb[2].YearTotal != common.StrToFloat(v1) || kjlrb[2].PeriodTotal != common.StrToFloat(v2) {
			panic(taxerr.NewUserV3(fmt.Sprintf("税金及附加校验与系统不一致，系统为：年：%s，本期：%s，税局为：年：%s，本期：%s", common.FloatToStr(kjlrb[2].YearTotal), common.FloatToStr(kjlrb[2].PeriodTotal), v1, v2), "请核实后重试"))
		}
		v1 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"其中：消费税")]/..//input)[1]`).MustText(), ",", "")
		v2 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"其中：消费税")]/..//input)[2]`).MustText(), ",", "")
		if kjlrb[3].YearTotal != common.StrToFloat(v1) || kjlrb[3].PeriodTotal != common.StrToFloat(v2) {
			panic(taxerr.NewUserV3(fmt.Sprintf("其中：消费税校验与系统不一致，系统为：年：%s，本期：%s，税局为：年：%s，本期：%s", common.FloatToStr(kjlrb[3].YearTotal), common.FloatToStr(kjlrb[3].PeriodTotal), v1, v2), "请核实后重试"))
		}
		v1 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"营业税")]/..//input)[1]`).MustText(), ",", "")
		v2 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"营业税")]/..//input)[2]`).MustText(), ",", "")
		if kjlrb[4].YearTotal != common.StrToFloat(v1) || kjlrb[4].PeriodTotal != common.StrToFloat(v2) {
			panic(taxerr.NewUserV3(fmt.Sprintf("营业税校验与系统不一致，系统为：年：%s，本期：%s，税局为：年：%s，本期：%s", common.FloatToStr(kjlrb[4].YearTotal), common.FloatToStr(kjlrb[4].PeriodTotal), v1, v2), "请核实后重试"))
		}
		v1 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"城市维护建设税")]/..//input)[1]`).MustText(), ",", "")
		v2 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"城市维护建设税")]/..//input)[2]`).MustText(), ",", "")
		if kjlrb[5].YearTotal != common.StrToFloat(v1) || kjlrb[5].PeriodTotal != common.StrToFloat(v2) {
			panic(taxerr.NewUserV3(fmt.Sprintf("城市维护建设税校验与系统不一致，系统为：年：%s，本期：%s，税局为：年：%s，本期：%s", common.FloatToStr(kjlrb[5].YearTotal), common.FloatToStr(kjlrb[5].PeriodTotal), v1, v2), "请核实后重试"))
		}
		v1 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"资源税")]/..//input)[1]`).MustText(), ",", "")
		v2 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"资源税")]/..//input)[2]`).MustText(), ",", "")
		if kjlrb[6].YearTotal != common.StrToFloat(v1) || kjlrb[6].PeriodTotal != common.StrToFloat(v2) {
			panic(taxerr.NewUserV3(fmt.Sprintf("资源税校验与系统不一致，系统为：年：%s，本期：%s，税局为：年：%s，本期：%s", common.FloatToStr(kjlrb[6].YearTotal), common.FloatToStr(kjlrb[6].PeriodTotal), v1, v2), "请核实后重试"))
		}
		v1 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"土地增值税")]/..//input)[1]`).MustText(), ",", "")
		v2 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"土地增值税")]/..//input)[2]`).MustText(), ",", "")
		if kjlrb[7].YearTotal != common.StrToFloat(v1) || kjlrb[7].PeriodTotal != common.StrToFloat(v2) {
			panic(taxerr.NewUserV3(fmt.Sprintf("土地增值税校验与系统不一致，系统为：年：%s，本期：%s，税局为：年：%s，本期：%s", common.FloatToStr(kjlrb[7].YearTotal), common.FloatToStr(kjlrb[7].PeriodTotal), v1, v2), "请核实后重试"))
		}
		v1 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"城镇土地使用税、房产税、车船税、印花税")]/..//input)[1]`).MustText(), ",", "")
		v2 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"城镇土地使用税、房产税、车船税、印花税")]/..//input)[2]`).MustText(), ",", "")
		if kjlrb[8].YearTotal != common.StrToFloat(v1) || kjlrb[8].PeriodTotal != common.StrToFloat(v2) {
			panic(taxerr.NewUserV3(fmt.Sprintf("城镇土地使用税、房产税、车船税、印花税校验与系统不一致，系统为：年：%s，本期：%s，税局为：年：%s，本期：%s", common.FloatToStr(kjlrb[8].YearTotal), common.FloatToStr(kjlrb[8].PeriodTotal), v1, v2), "请核实后重试"))
		}
		v1 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"教育费附加、矿产资源补偿费、排污费")]/..//input)[1]`).MustText(), ",", "")
		v2 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"教育费附加、矿产资源补偿费、排污费")]/..//input)[2]`).MustText(), ",", "")
		if kjlrb[9].YearTotal != common.StrToFloat(v1) || kjlrb[9].PeriodTotal != common.StrToFloat(v2) {
			panic(taxerr.NewUserV3(fmt.Sprintf("城镇土地使用税、房产税、车船税、印花税校验与系统不一致，系统为：年：%s，本期：%s，税局为：年：%s，本期：%s", common.FloatToStr(kjlrb[9].YearTotal), common.FloatToStr(kjlrb[9].PeriodTotal), v1, v2), "请核实后重试"))
		}
		v1 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"销售费用")]/..//input)[1]`).MustText(), ",", "")
		v2 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"销售费用")]/..//input)[2]`).MustText(), ",", "")
		if kjlrb[10].YearTotal != common.StrToFloat(v1) || kjlrb[10].PeriodTotal != common.StrToFloat(v2) {
			panic(taxerr.NewUserV3(fmt.Sprintf("销售费用校验与系统不一致，系统为：年：%s，本期：%s，税局为：年：%s，本期：%s", common.FloatToStr(kjlrb[10].YearTotal), common.FloatToStr(kjlrb[10].PeriodTotal), v1, v2), "请核实后重试"))
		}
		v1 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"其中：商品维修费")]/..//input)[1]`).MustText(), ",", "")
		v2 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"其中：商品维修费")]/..//input)[2]`).MustText(), ",", "")
		if kjlrb[11].YearTotal != common.StrToFloat(v1) || kjlrb[11].PeriodTotal != common.StrToFloat(v2) {
			panic(taxerr.NewUserV3(fmt.Sprintf("其中：商品维修费校验与系统不一致，系统为：年：%s，本期：%s，税局为：年：%s，本期：%s", common.FloatToStr(kjlrb[11].YearTotal), common.FloatToStr(kjlrb[11].PeriodTotal), v1, v2), "请核实后重试"))
		}
		v1 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"广告费和业务宣传费")]/..//input)[1]`).MustText(), ",", "")
		v2 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"广告费和业务宣传费")]/..//input)[2]`).MustText(), ",", "")
		if kjlrb[12].YearTotal != common.StrToFloat(v1) || kjlrb[12].PeriodTotal != common.StrToFloat(v2) {
			panic(taxerr.NewUserV3(fmt.Sprintf("广告费和业务宣传费校验与系统不一致，系统为：年：%s，本期：%s，税局为：年：%s，本期：%s", common.FloatToStr(kjlrb[12].YearTotal), common.FloatToStr(kjlrb[12].PeriodTotal), v1, v2), "请核实后重试"))
		}
		v1 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"管理费用")]/..//input)[1]`).MustText(), ",", "")
		v2 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"管理费用")]/..//input)[2]`).MustText(), ",", "")
		if kjlrb[13].YearTotal != common.StrToFloat(v1) || kjlrb[13].PeriodTotal != common.StrToFloat(v2) {
			panic(taxerr.NewUserV3(fmt.Sprintf("管理费用校验与系统不一致，系统为：年：%s，本期：%s，税局为：年：%s，本期：%s", common.FloatToStr(kjlrb[13].YearTotal), common.FloatToStr(kjlrb[13].PeriodTotal), v1, v2), "请核实后重试"))
		}
		v1 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"其中：开办费")]/..//input)[1]`).MustText(), ",", "")
		v2 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"其中：开办费")]/..//input)[2]`).MustText(), ",", "")
		if kjlrb[14].YearTotal != common.StrToFloat(v1) || kjlrb[14].PeriodTotal != common.StrToFloat(v2) {
			panic(taxerr.NewUserV3(fmt.Sprintf("其中：开办费校验与系统不一致，系统为：年：%s，本期：%s，税局为：年：%s，本期：%s", common.FloatToStr(kjlrb[14].YearTotal), common.FloatToStr(kjlrb[14].PeriodTotal), v1, v2), "请核实后重试"))
		}
		v1 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"业务招待费")]/..//input)[1]`).MustText(), ",", "")
		v2 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"业务招待费")]/..//input)[2]`).MustText(), ",", "")
		if kjlrb[15].YearTotal != common.StrToFloat(v1) || kjlrb[15].PeriodTotal != common.StrToFloat(v2) {
			panic(taxerr.NewUserV3(fmt.Sprintf("业务招待费校验与系统不一致，系统为：年：%s，本期：%s，税局为：年：%s，本期：%s", common.FloatToStr(kjlrb[15].YearTotal), common.FloatToStr(kjlrb[15].PeriodTotal), v1, v2), "请核实后重试"))
		}
		v1 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"研究费用")]/..//input)[1]`).MustText(), ",", "")
		v2 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"研究费用")]/..//input)[2]`).MustText(), ",", "")
		if kjlrb[16].YearTotal != common.StrToFloat(v1) || kjlrb[16].PeriodTotal != common.StrToFloat(v2) {
			panic(taxerr.NewUserV3(fmt.Sprintf("研究费用校验与系统不一致，系统为：年：%s，本期：%s，税局为：年：%s，本期：%s", common.FloatToStr(kjlrb[16].YearTotal), common.FloatToStr(kjlrb[16].PeriodTotal), v1, v2), "请核实后重试"))
		}
		v1 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"财务费用")]/..//input)[1]`).MustText(), ",", "")
		v2 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"财务费用")]/..//input)[2]`).MustText(), ",", "")
		if kjlrb[17].YearTotal != common.StrToFloat(v1) || kjlrb[17].PeriodTotal != common.StrToFloat(v2) {
			panic(taxerr.NewUserV3(fmt.Sprintf("财务费用校验与系统不一致，系统为：年：%s，本期：%s，税局为：年：%s，本期：%s", common.FloatToStr(kjlrb[17].YearTotal), common.FloatToStr(kjlrb[17].PeriodTotal), v1, v2), "请核实后重试"))
		}
		v1 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"其中：利息费用（收入以－号填列）")]/..//input)[1]`).MustText(), ",", "")
		v2 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"其中：利息费用（收入以－号填列）")]/..//input)[2]`).MustText(), ",", "")
		if kjlrb[18].YearTotal != common.StrToFloat(v1) || kjlrb[18].PeriodTotal != common.StrToFloat(v2) {
			panic(taxerr.NewUserV3(fmt.Sprintf("其中：利息费用（收入以－号填列）校验与系统不一致，系统为：年：%s，本期：%s，税局为：年：%s，本期：%s", common.FloatToStr(kjlrb[18].YearTotal), common.FloatToStr(kjlrb[18].PeriodTotal), v1, v2), "请核实后重试"))
		}
		v1 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"加：投资收益（损失以－号填列）")]/..//input)[1]`).MustText(), ",", "")
		v2 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"加：投资收益（损失以－号填列）")]/..//input)[2]`).MustText(), ",", "")
		if kjlrb[19].YearTotal != common.StrToFloat(v1) || kjlrb[19].PeriodTotal != common.StrToFloat(v2) {
			panic(taxerr.NewUserV3(fmt.Sprintf("加：投资收益（损失以－号填列）校验与系统不一致，系统为：年：%s，本期：%s，税局为：年：%s，本期：%s", common.FloatToStr(kjlrb[19].YearTotal), common.FloatToStr(kjlrb[19].PeriodTotal), v1, v2), "请核实后重试"))
		}
		v1 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"二、营业利润（亏损以－号填列）")]/..//input)[1]`).MustText(), ",", "")
		v2 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"二、营业利润（亏损以－号填列）")]/..//input)[2]`).MustText(), ",", "")
		if kjlrb[20].YearTotal != common.StrToFloat(v1) || kjlrb[20].PeriodTotal != common.StrToFloat(v2) {
			panic(taxerr.NewUserV3(fmt.Sprintf(" 二、营业利润（亏损以－号填列）校验与系统不一致，系统为：年：%s，本期：%s，税局为：年：%s，本期：%s", common.FloatToStr(kjlrb[20].YearTotal), common.FloatToStr(kjlrb[20].PeriodTotal), v1, v2), "请核实后重试"))
		}
		v1 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"加：营业外收入")]/..//input)[1]`).MustText(), ",", "")
		v2 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"加：营业外收入")]/..//input)[2]`).MustText(), ",", "")
		if kjlrb[21].YearTotal != common.StrToFloat(v1) || kjlrb[21].PeriodTotal != common.StrToFloat(v2) {
			panic(taxerr.NewUserV3(fmt.Sprintf("加：营业外收入校验与系统不一致，系统为：年：%s，本期：%s，税局为：年：%s，本期：%s", common.FloatToStr(kjlrb[21].YearTotal), common.FloatToStr(kjlrb[21].PeriodTotal), v1, v2), "请核实后重试"))
		}
		v1 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"其中：政府补助")]/..//input)[1]`).MustText(), ",", "")
		v2 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"其中：政府补助")]/..//input)[2]`).MustText(), ",", "")
		if kjlrb[22].YearTotal != common.StrToFloat(v1) || kjlrb[22].PeriodTotal != common.StrToFloat(v2) {
			panic(taxerr.NewUserV3(fmt.Sprintf("其中：政府补助校验与系统不一致，系统为：年：%s，本期：%s，税局为：年：%s，本期：%s", common.FloatToStr(kjlrb[22].YearTotal), common.FloatToStr(kjlrb[22].PeriodTotal), v1, v2), "请核实后重试"))
		}
		v1 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"减：营业外支出")]/..//input)[1]`).MustText(), ",", "")
		v2 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"减：营业外支出")]/..//input)[2]`).MustText(), ",", "")
		if kjlrb[23].YearTotal != common.StrToFloat(v1) || kjlrb[23].PeriodTotal != common.StrToFloat(v2) {
			panic(taxerr.NewUserV3(fmt.Sprintf("减：营业外支出校验与系统不一致，系统为：年：%s，本期：%s，税局为：年：%s，本期：%s", common.FloatToStr(kjlrb[23].YearTotal), common.FloatToStr(kjlrb[23].PeriodTotal), v1, v2), "请核实后重试"))
		}
		v1 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"其中：坏账损失")]/..//input)[1]`).MustText(), ",", "")
		v2 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"其中：坏账损失")]/..//input)[2]`).MustText(), ",", "")
		if kjlrb[24].YearTotal != common.StrToFloat(v1) || kjlrb[24].PeriodTotal != common.StrToFloat(v2) {
			panic(taxerr.NewUserV3(fmt.Sprintf("其中：坏账损失校验与系统不一致，系统为：年：%s，本期：%s，税局为：年：%s，本期：%s", common.FloatToStr(kjlrb[24].YearTotal), common.FloatToStr(kjlrb[24].PeriodTotal), v1, v2), "请核实后重试"))
		}
		v1 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"无法收回的长期债券投资损失")]/..//input)[1]`).MustText(), ",", "")
		v2 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"无法收回的长期债券投资损失")]/..//input)[2]`).MustText(), ",", "")
		if kjlrb[25].YearTotal != common.StrToFloat(v1) || kjlrb[25].PeriodTotal != common.StrToFloat(v2) {
			panic(taxerr.NewUserV3(fmt.Sprintf("无法收回的长期债券投资损失校验与系统不一致，系统为：年：%s，本期：%s，税局为：年：%s，本期：%s", common.FloatToStr(kjlrb[25].YearTotal), common.FloatToStr(kjlrb[25].PeriodTotal), v1, v2), "请核实后重试"))
		}
		v1 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"无法收回的长期股权投资损失")]/..//input)[1]`).MustText(), ",", "")
		v2 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"无法收回的长期股权投资损失")]/..//input)[2]`).MustText(), ",", "")
		if kjlrb[26].YearTotal != common.StrToFloat(v1) || kjlrb[26].PeriodTotal != common.StrToFloat(v2) {
			panic(taxerr.NewUserV3(fmt.Sprintf("无法收回的长期股权投资损失校验与系统不一致，系统为：年：%s，本期：%s，税局为：年：%s，本期：%s", common.FloatToStr(kjlrb[26].YearTotal), common.FloatToStr(kjlrb[26].PeriodTotal), v1, v2), "请核实后重试"))
		}
		v1 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"自然灾害等不可抗力因素造成的损失")]/..//input)[1]`).MustText(), ",", "")
		v2 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"自然灾害等不可抗力因素造成的损失")]/..//input)[2]`).MustText(), ",", "")
		if kjlrb[27].YearTotal != common.StrToFloat(v1) || kjlrb[27].PeriodTotal != common.StrToFloat(v2) {
			panic(taxerr.NewUserV3(fmt.Sprintf("自然灾害等不可抗力因素造成的损失校验与系统不一致，系统为：年：%s，本期：%s，税局为：年：%s，本期：%s", common.FloatToStr(kjlrb[27].YearTotal), common.FloatToStr(kjlrb[27].PeriodTotal), v1, v2), "请核实后重试"))
		}
		v1 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"税收滞纳金")]/..//input)[1]`).MustText(), ",", "")
		v2 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"税收滞纳金")]/..//input)[2]`).MustText(), ",", "")
		if kjlrb[28].YearTotal != common.StrToFloat(v1) || kjlrb[28].PeriodTotal != common.StrToFloat(v2) {
			panic(taxerr.NewUserV3(fmt.Sprintf("税收滞纳金校验与系统不一致，系统为：年：%s，本期：%s，税局为：年：%s，本期：%s", common.FloatToStr(kjlrb[28].YearTotal), common.FloatToStr(kjlrb[28].PeriodTotal), v1, v2), "请核实后重试"))
		}
		v1 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"三、利润总额（亏损总额以－号填列）")]/..//input)[1]`).MustText(), ",", "")
		v2 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"三、利润总额（亏损总额以－号填列）")]/..//input)[2]`).MustText(), ",", "")
		if kjlrb[29].YearTotal != common.StrToFloat(v1) || kjlrb[29].PeriodTotal != common.StrToFloat(v2) {
			panic(taxerr.NewUserV3(fmt.Sprintf("三、利润总额（亏损总额以－号填列）校验与系统不一致，系统为：年：%s，本期：%s，税局为：年：%s，本期：%s", common.FloatToStr(kjlrb[29].YearTotal), common.FloatToStr(kjlrb[29].PeriodTotal), v1, v2), "请核实后重试"))
		}
		v1 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"减：所得税费用")]/..//input)[1]`).MustText(), ",", "")
		v2 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"减：所得税费用")]/..//input)[2]`).MustText(), ",", "")
		if kjlrb[30].YearTotal != common.StrToFloat(v1) || kjlrb[30].PeriodTotal != common.StrToFloat(v2) {
			panic(taxerr.NewUserV3(fmt.Sprintf("减：所得税费用校验与系统不一致，系统为：年：%s，本期：%s，税局为：年：%s，本期：%s", common.FloatToStr(kjlrb[30].YearTotal), common.FloatToStr(kjlrb[30].PeriodTotal), v1, v2), "请核实后重试"))
		}
		v1 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"四、净利润（净亏损以－号填列）")]/..//input)[1]`).MustText(), ",", "")
		v2 = strings.ReplaceAll(MustElementX(newp1, `(//td[contains(text(),"四、净利润（净亏损以－号填列）")]/..//input)[2]`).MustText(), ",", "")
		if kjlrb[31].YearTotal != common.StrToFloat(v1) || kjlrb[31].PeriodTotal != common.StrToFloat(v2) {
			panic(taxerr.NewUserV3(fmt.Sprintf(" 四、净利润（净亏损以－号填列）校验与系统不一致，系统为：年：%s，本期：%s，税局为：年：%s，本期：%s", common.FloatToStr(kjlrb[31].YearTotal), common.FloatToStr(kjlrb[31].PeriodTotal), v1, v2), "请核实后重试"))
		}
		//点击现金流量表
		if info.XjllbSb {
			if len(kjxjllb) != 1 {
				panic(taxerr.NewUserV3("现金流量表未取数", "请取数后重试"))
			}
			utils.Sleep(3)
			if newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustHas(`#divSheetlist > li:nth-child(3) > a`) {
				newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#divSheetlist > li:nth-child(3) > a`).MustClick() //点击现金流量表
				//var kjxjllb []models.KjXjllb销售产成品、商品、提供劳务收到的现金
				//销售产成品、商品、提供劳务收到的现金
				common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"销售产成品、商品、提供劳务收到的现金")]/..//input)[2]`, common.FloatToStr(kjxjllb[0].PeriodTotal))
				utils.Sleep(0.5)
				//收到其他与经营活动有关的现金
				common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"收到其他与经营活动有关的现金")]/..//input)[2]`, common.FloatToStr(kjxjllb[1].PeriodTotal))
				utils.Sleep(0.5)
				//购买原材料、商品、接受劳务支付的现金
				common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"购买原材料、商品、接受劳务支付的现金")]/..//input)[2]`, common.FloatToStr(kjxjllb[2].PeriodTotal))
				utils.Sleep(0.5)
				//支付的职工薪酬
				common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"支付的职工薪酬")]/..//input)[2]`, common.FloatToStr(kjxjllb[3].PeriodTotal))
				utils.Sleep(0.5)
				//支付的税费
				common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"支付的税费")]/..//input)[2]`, common.FloatToStr(kjxjllb[4].PeriodTotal))
				utils.Sleep(0.5)
				//支付其他与经营活动有关的现金
				common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"支付其他与经营活动有关的现金")]/..//input)[2]`, common.FloatToStr(kjxjllb[5].PeriodTotal))
				utils.Sleep(0.5)
				//收回短期投资、长期债券投资和长期股权投资收到的现金
				common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"收回短期投资、长期债券投资和长期股权投资收到的现金")]/..//input)[2]`, common.FloatToStr(kjxjllb[7].PeriodTotal))
				utils.Sleep(0.5)
				//取得投资收益收到的现金
				common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"取得投资收益收到的现金")]/..//input)[2]`, common.FloatToStr(kjxjllb[8].PeriodTotal))
				utils.Sleep(0.5)
				//处置固定资产、无形资产和其他非流动资产收回的现金净额
				common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"处置固定资产、无形资产和其他非流动资产收回的现金净额")]/..//input)[2]`, common.FloatToStr(kjxjllb[9].PeriodTotal))
				utils.Sleep(0.5)
				//短期投资、长期债券投资和长期股权投资支付的现金
				common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"短期投资、长期债券投资和长期股权投资支付的现金")]/..//input)[2]`, common.FloatToStr(kjxjllb[10].PeriodTotal))
				utils.Sleep(0.5)
				//购建固定资产、无形资产和其他非流动资产支付的现金
				common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"购建固定资产、无形资产和其他非流动资产支付的现金")]/..//input)[2]`, common.FloatToStr(kjxjllb[11].PeriodTotal))
				utils.Sleep(0.5)
				//取得借款收到的现金
				common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"取得借款收到的现金")]/..//input)[2]`, common.FloatToStr(kjxjllb[13].PeriodTotal))
				utils.Sleep(0.5)
				//吸收投资者投资收到的现金
				common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"吸收投资者投资收到的现金")]/..//input)[2]`, common.FloatToStr(kjxjllb[14].PeriodTotal))
				utils.Sleep(0.5)
				//偿还借款本金支付的现金
				common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"偿还借款本金支付的现金")]/..//input)[2]`, common.FloatToStr(kjxjllb[15].PeriodTotal))
				utils.Sleep(0.5)
				//偿还借款利息支付的现金
				common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"偿还借款利息支付的现金")]/..//input)[2]`, common.FloatToStr(kjxjllb[16].PeriodTotal))
				utils.Sleep(0.5)
				//分配利润支付的现金
				common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"分配利润支付的现金")]/..//input)[2]`, common.FloatToStr(kjxjllb[17].PeriodTotal))
				utils.Sleep(0.5)
				//加：期初现金余额
				common.InputX(newp1.Timeout(common.ClickTimeOut).MustElement("#frmFrame").MustFrame().MustElement(`#frmMain`).MustFrame().MustElement(`#frmSheet`).MustFrame(), `(//td[contains(text(),"加：期初现金余额")]/..//input)[2]`, common.FloatToStr(kjxjllb[20].PeriodTotal))
			} else {
				panic("未生成现金流量表！")
			}
		}

		//点击申报
		utils.Sleep(3)
		rr = newp1.MustWaitRequestIdle()
		newp1.Timeout(common.ClickTimeOut).MustSearch(`提交申报`).MustClick()
		rr()
		utils.Sleep(3)
		if newp1.MustHasX(`//div[@class="t-dialog__body t-dialog__body__icon"]`) {
			text := newp1.MustElementX(`//div[@class="t-dialog__body t-dialog__body__icon"]`).MustText()
			if strings.Contains(text, "不符") {
				panic(taxerr.NewUserV3(text, "请核实后重试"))
			}
		}
		if newp1.MustHasX(`//div[@class="drawer-body"]//p`) && newp1.MustElementX(`//div[@class="drawer-body"]//p`).MustVisible() {
			text := newp1.MustElementX(`//div[@class="drawer-body"]//p`).MustText()
			panic(taxerr.NewUserV3(text, "请核实后重试"))
		}
		newp1.Timeout(common.ClickTimeOut).MustElementX(`//input[@placeholder='真']`).MustClick()
		newp1.Timeout(common.ClickTimeOut).MustElementX(`//input[@placeholder='真']`).MustInput("真")
		newp1.Timeout(common.ClickTimeOut).MustElementX(`//input[@placeholder='实']`).MustClick()
		newp1.Timeout(common.ClickTimeOut).MustElementX(`//input[@placeholder='实']`).MustInput("实")
		newp1.Timeout(common.ClickTimeOut).MustElementX(`//input[@placeholder='责']`).MustClick()
		newp1.Timeout(common.ClickTimeOut).MustElementX(`//input[@placeholder='责']`).MustInput("责")
		newp1.Timeout(common.ClickTimeOut).MustElementX(`//input[@placeholder='任']`).MustClick()
		newp1.Timeout(common.ClickTimeOut).MustElementX(`//input[@placeholder='任']`).MustInput("任")
		utils.Sleep(3)
		rr = newp1.MustWaitRequestIdle()
		newp1.Timeout(common.ClickTimeOut).MustElementX(`//span[contains(text(),"确定")]`).MustClick()
		rr()
		//utils.Sleep(40)

		text := newp1.Timeout(10 * common.ClickTimeOut).MustElementX(`//div[@class="gt-result-title"]`).MustText()
		utils.Sleep(5)
		path := SaveErrImg(newp1, info)
		task.Result.BusinessImg = path
		//task.Result.BusinessStatus = variable.TaxSuccess
		task.Result.BusinessLog = text
	})
	if err != nil {
		task.Result.BusinessStatus = variable.TaxFail
		task.Result.BusinessLog = common.HandleError(ctx, err).Error()
		return
	}
	return
}
