package models

type CollectionData struct {
	Err  string `json:"err"`
	Data any    `json:"data"`
}

// 注册信息
type GsRegInfo struct {
	TaxpayerNumer                     string `json:"taxpayerNumer"`                     // 纳税人识别号
	TaxpayerName                      string `json:"taxpayerName"`                      // 纳税人名称
	TaxpayerStatus                    string `json:"taxpayerStatus"`                    // 纳税人状态
	SubjectRegistrationType           string `json:"subjectRegistrationType"`           // 课征主体登记类型
	RegistrationType                  string `json:"registrationType"`                  // 登记注册类型
	OrganizationCode                  string `json:"organizationCode"`                  // 组织机构代码
	TaxAuthorities                    string `json:"taxAuthorities"`                    // 主管税务机关
	Taxsuks                           string `json:"taxsuks"`                           // 主管税务科所
	TaxAdmin                          string `json:"taxAdmin"`                          // 税收管理员
	RegisteredCapital                 string `json:"registeredCapital"`                 // 注册资本
	TotalInvestment                   string `json:"totalInvestment"`                   // 投资总额
	Gykglx                            string `json:"gykglx"`                            // 国有控股类型
	GyInvestmentProportion            string `json:"gyInvestmentProportion"`            // 国有投资比例
	NaturalPeopleInvestmentProportion string `json:"naturalPeopleInvestmentProportion"` // 自然人投资比例
	ForeignInvestmentRatio            string `json:"foreignInvestmentRatio"`            // 外资投资比例
	LegalRepresentativeName           string `json:"legalRepresentativeName"`           // 法定代表人姓名
	LegalRepresentativeIDCard         string `json:"legalRepresentativeIDCard"`         // 法定代表人身份证号码
	LegalRepresentativePhone          string `json:"legalRepresentativePhone"`          // 法定代表人移动电话
	LegalRepresentativeTel            string `json:"legalRepresentativeTel"`            // 法定代表人固定电话
	FinancialManagerName              string `json:"financialManagerName"`              // 财务负责人姓名
	FinancialManagerIDCard            string `json:"financialManagerIDCard"`            // 财务负责人身份证号码
	FinancialManagerPhone             string `json:"financialManagerPhone"`             // 财务负责人移动电话
	FinancialManagerTel               string `json:"financialManagerTel"`               // 财务负责人固定电话
	TaxCollectorName                  string `json:"taxCollectorName"`                  // 办税人姓名
	TaxCollertorIDCard                string `json:"taxCollertorIDCard"`                // 办税人身份证号码
	TaxCollertorPhone                 string `json:"taxCollertorPhone"`                 // 办税人手机号码
	TaxCollertorTel                   string `json:"taxCollertorTel"`                   // 办税人固定电话

	RegistrAddress    string `json:"registrAddress"`    // 注册地址
	ProductionAddress string `json:"productionAddress"` // 生产经营地址
	NatureOfBusiness  string `json:"natureOfBusiness"`  //经营范围

	Nsrlx string `json:"nsrlx"` //纳税人类型
	Kjzd  string `json:"kjzd"`  //会计制度
}

// 国税系统_抓取_税种
type GsTaxCategory struct {
	ID                  uint    `json:"id" gorm:"primary_key"`
	ComID               uint    `json:"comId"`               // 小程序ID
	Status              int     `json:"status"`              // 状态:0-无效,1-启用
	Seq                 int     `json:"seq"`                 // 排序
	Remark              string  `json:"remark"`              // 备注说明
	CollectionProject   string  `json:"collectionProject"`   // 征收项目
	CollectionItems     string  `json:"collectionItems"`     // 征收品目
	CollectionSub       string  `json:"collectionSub"`       // 征收子目
	ValidityPeriodStart string  `json:"validityPeriodStart"` // 认定有效期起
	ValidityPeriodEnd   string  `json:"validityPeriodEnd"`   // 认定有效期止
	Rate                string  `json:"rate"`                // 税率或单位税额
	CollectionAgency    string  `json:"collectionAgency"`    // 征收代理方式3
	Type                string  `json:"type"`
	YhHdbl              float64 `json:"yhHdbl"`
	ByHand              int     `json:"byHand"`
	Hdjye               string  `json:"hdjye"`                       //核定经营额
	Dqde                string  `json:"dqde"`                        //定额核定
	CollectionItemsDm   string  `json:"collectionItemsDm,omitempty"` // 征收品目代码 补充用
}

// 中华人民共和国企业所得税月（季）度预缴纳税申报表（A类） 2021之前
type GsTaxQuarter struct {
	YysrLj               string `json:"yysrLj"`               // 1：营业收入
	YycbLj               string `json:"yycbLj"`               // 2：营业成本
	LrzeLj               string `json:"lrzeLj"`               // 3：利润总额
	TdywjsdynssdeLj      string `json:"tdywjsdynssdeLj"`      // 4：加：特定业务计算的应纳税所得额
	BzssrLj              string `json:"bzssrLj"`              // 5：减：不征税收入
	MssrLj               string `json:"mssrLj"`               // 6：减：免税收入、减计收入、所得减免等优惠金额（填写A201010）
	GdzcjszjkctjeLj      string `json:"gdzcjszjkctjeLj"`      // 7：减：固定资产加速折旧（扣除）调减额（填写A201020）
	MbyqndksLj           string `json:"mbyqndksLj"`           // 8：减：弥补以前年度亏损
	SjlreLj              string `json:"sjlreLj"`              // 9：实际利润额（3&#43;4-5-6-7-8） \ 按照上一纳税年度应纳税所得额平均额确定的应纳税所得额
	SlLj                 string `json:"slLj"`                 // 10：税率(25%)
	YnsdseLj             string `json:"ynsdseLj"`             // 11：应纳所得税额（9×10）
	JmsdseLj             string `json:"jmsdseLj"`             // 12：减：减免所得税额（填写A201030）
	SjyyjsdseLj          string `json:"sjyyjsdseLj"`          // 13：减：实际已缴纳所得税额
	TdywyjzsdseLj        string `json:"tdywyjzsdseLj"`        // 14：减：特定业务预缴（征）所得税额
	YbtsdseLj            string `json:"ybtsdseLj"`            // 15：本期应补（退）所得税额（11-12-13-14） \ 税务机关确定的本期应纳所得税额
	ZjgybtsdseBq         string `json:"zjgybtsdseBq"`         // 16：总机构本期分摊应补（退）所得税额（17&#43;18&#43;19）
	ZjgyftsdseBq         string `json:"zjgyftsdseBq"`         // 17：其中：总机构分摊应补（退）所得税额（15×总机构分摊比例 （22） ）
	CzjzfpsdseBq         string `json:"czjzfpsdseBq"`         // 18：财政集中分配应补（退）所得税额（15×财政集中分配比例 （23） ）
	ZjgdlscjybmyftsdseBq string `json:"zjgdlscjybmyftsdseBq"` // 19： 总机构具有主体生产经营职能的部门分摊所得税额（15×全部分支机构分摊比例（24） × 总机构具有主体生产经营职能部门分摊比例 （25） )
	Fpbl                 string `json:"fpbl"`                 // 20： 分支机构本期分摊比例
	FzjgfpsdseBq         string `json:"fzjgfpsdseBq"`         // 21： 分支机构本期分摊应补（退）所得税额
	Zjgftbl              string `json:"zjgftbl"`              // 22：总机构分摊比例
	Zjgczjzftbl          string `json:"zjgczjzftbl"`          // 23：财政集中分配比例
	Fzjgftbl             string `json:"fzjgftbl"`             // 24：全部分支机构分摊比例
	Dlscjybmftbl         string `json:"dlscjybmftbl"`         // 25：总机构具有主体生产经营职能部门分摊比例
	Qccyrs               string `json:"qccyrs"`               //季初从业人数
	Qmcyrs               string `json:"qmcyrs"`               //季末从业人数
	Gjxzhjzhy            int    `json:"gjxzhjzhy"`            //
	Jbr                  string `json:"jbr"`
	Jbrzyzjhm            string `json:"jbrzyzjhm"`
	Qczcze               string `json:"qczcze"`
	Qmzcze               string `json:"qmzcze"`
	Kjxzxqy              int    `json:"kjxzxqy"`
	Jsrgdynssx           int    `json:"jsrgdynssx"`
	Xxwlqy               int    `json:"xxwlqy"`
	Gxjsqy               int    `json:"gxjsqy"`

	Qccyrs1 string `json:"qccyrs1"`
	Qccyrs2 string `json:"qccyrs2"`
	Qccyrs3 string `json:"qccyrs3"`
	Qccyrs4 string `json:"qccyrs4"`
	Qmcyrs1 string `json:"qmcyrs1"`
	Qmcyrs2 string `json:"qmcyrs2"`
	Qmcyrs3 string `json:"qmcyrs3"`
	Qmcyrs4 string `json:"qmcyrs4"`

	Qczcze1 string `json:"qczcze1"`
	Qczcze2 string `json:"qczcze2"`
	Qczcze3 string `json:"qczcze3"`
	Qczcze4 string `json:"qczcze4"`
	Qmzcze1 string `json:"qmzcze1"`
	Qmzcze2 string `json:"qmzcze2"`
	Qmzcze3 string `json:"qmzcze3"`
	Qmzcze4 string `json:"qmzcze4"`

	Yjfs       int    `json:"yjfs"`
	Qylx       int    `json:"qylx"`
	Yhjn       string `json:"yhjn"`
	Yhjnstatus int    `json:"yhjnstatus"`
	Yhjntext   string `json:"yhjntext"`
}

// 2021之后
type GsTaxQuarterNewa struct {
	K01001Status  int     `json:"k01001Status"`
	K01001        float64 `json:"k01001"`
	K01002Status  int     `json:"k01002Status"`
	K01002        float64 `json:"k01002"`
	Y01001Status  int     `json:"y01001Status"`
	Y01001        string  `json:"y01001"`
	Yysr          float64 `json:"yysr"`          //营业收入 1
	Yycb          float64 `json:"yycb"`          //营业收入 2
	Lrze          float64 `json:"lrze"`          //利润总额 3
	Tdywjsdynssde float64 `json:"tdywjsdynssde"` //加：特定业务计算的应纳税所得额 4
	Bzssr         float64 `json:"bzssr"`         //减：不征税收入 5
	Zcjszj        float64 `json:"zcjszj"`        //减：资产加速折旧、摊销（扣除）调减额（填写A201020） 6
	Mssr          float64 `json:"mssr"`          //减：免税收入、减计收入、加计扣除（7.1+7.2+……） 7
	Sdsjm         float64 `json:"sdsjm"`         //减：所得减免（8.1+8.2+……） 8
	Mbyqndks      float64 `json:"mbyqndks"`      //减：弥补以前年度亏损 9
	Sjlre         float64 `json:"sjlre"`         //实际利润额（3+4-5-6-7-8-9） \ 按照上一纳税年度应纳税所得额平均额确定的应纳税所得额 10
	Sl            float64 `json:"sl"`            //税率(25%) 11
	Ynssde        float64 `json:"ynssde"`        //应纳所得税额（10×11） 12
	Jmsdse        float64 `json:"jmsdse"`        //减：减免所得税额（13.1+13.2+……） 13
	Xwqyjm        float64 `json:"xwqyjm"`        //符合条件的小型微利企业减免企业所得税 13.1
	Bnsjyjn       float64 `json:"bnsjyjn"`       //减：本年实际已缴纳所得税额 14
	Tdyeyj        float64 `json:"tdyeyj"`        //减：特定业务预缴（征）所得税额		 15
	Bqybt         float64 `json:"bqybt"`         //本期应补（退）所得税额（12-13-14-15） \ 税务机关确定的本期应纳所得税额 16
	Zyjsr         float64 `json:"zyjsr"`         //中央级收入实际应纳税额[本期：16行×60%或(18行+20行)×60%+19或22行×60%]
	Dfjsr         float64 `json:"dfjsr"`         //地方级收入应纳税额[本期：16行×40%或(18行+20行)×40%或22行×40%]
	MzzzqStatus   int     `json:"mzzzqStatus"`   //减：民族自治地区企业所得税地方分享部分 0无 1免征 2减征
	MzzzqFd       string  `json:"mzzzqFd"`       //减征幅度
	MzzzqBq       float64 `json:"mzzzqBq"`       //本期实际减免金额（FZ2×减征幅度）
	MzzzqBn       float64 `json:"mzzzqBn"`       //本机构本年累计的（23行的本年累计）
	MzzzqBnym     float64 `json:"mzzzqBnym"`     //本年累计应减免金额（总机构及分支机构的本年累计，总机构填报）
	Dfjsrsjynse   float64 `json:"dfjsrsjynse"`   //地方级收入实际应纳税额（本期：FZ2-23）
	Sjybtse       float64 `json:"sjybtse"`       //实际应补（退）所得税额（本期：FZ1+FZ3）

	Xxwlqy  int    `json:"xxwlqy"` //1是 0否 小微企业
	Xzhy    int    `json:"xzhy"`   //1是 0否 限制行业
	Qccyrs1 string `json:"qccyrs1"`
	Qccyrs2 string `json:"qccyrs2"`
	Qccyrs3 string `json:"qccyrs3"`
	Qccyrs4 string `json:"qccyrs4"`
	Qmcyrs1 string `json:"qmcyrs1"`
	Qmcyrs2 string `json:"qmcyrs2"`
	Qmcyrs3 string `json:"qmcyrs3"`
	Qmcyrs4 string `json:"qmcyrs4"`
	Qczcze1 string `json:"qczcze1"`
	Qczcze2 string `json:"qczcze2"`
	Qczcze3 string `json:"qczcze3"`
	Qczcze4 string `json:"qczcze4"`
	Qmzcze1 string `json:"qmzcze1"`
	Qmzcze2 string `json:"qmzcze2"`
	Qmzcze3 string `json:"qmzcze3"`
	Qmzcze4 string `json:"qmzcze4"`
}

type GsTaxQuarterFb1 struct {
	Code    string  `json:"code"`
	Status  int     `json:"status"`
	Amount  float64 `json:"amount"`
	Remark  string  `json:"remark"`
	Remark2 string  `json:"remark2"`
}

// 中华人民共和国企业所得税月（季）度预缴纳税申报表（B类）
type GsTaxQuarterB struct {
	Hdzsfs        string  `json:"hdzsfs"`        // 核定征收方式
	Srze          float64 `json:"srze"`          // 1：收入总额
	JBzssr        float64 `json:"jBzssr"`        // 2：减：不征税收入
	JMssr         float64 `json:"jMssr"`         // 2：减：免税收入（4&#43;5&#43;8&#43;9）
	Gzlxsr        float64 `json:"gzlxsr"`        // 4: 国债利息收入免征企业所得税
	Fhtjdjmqyzjgx float64 `json:"fhtjdjmqyzjgx"` // 5:符合条件的居民企业之间的股息、红利等权益性投资收益免征企业所得税
	QzYbgxhl      float64 `json:"qzYbgxhl"`
	QzTghgttz     float64 `json:"qzTghgttz"`     // 6其中：通过沪港通投资且连续持有H股满12个月取得的股息红利所得免征企业所得税
	QzTgsgttz     float64 `json:"qzTgsgttz"`     // 7通过深港通投资且连续持有H股满12个月取得的股息红利所得免征企业所得税
	Jmqycycxqy    float64 `json:"jmqycycxqy"`    // 8居民企业持有创新企业CDR取得的股息红利所得免征企业所得税
	Fhtjdjmqy     float64 `json:"fhtjdjmqy"`     // 9符合条件的居民企业之间属于股息、红利性质的永续债利息收入免征企业所得税
	Tzzczqtzjjfp  float64 `json:"tzzczqtzjjfp"`  // 10投资者从证券投资基金分配中取得的收入免征企业所得税
	Qdddfzfzqlxsr float64 `json:"qdddfzfzqlxsr"` // 11取得的地方政府债券利息收入免征企业所得税
	Yssre         float64 `json:"yssre"`         // 12应税收入额（1-2-3） \ 成本费用总额
	Swjghddyssdl  float64 `json:"swjghddyssdl"`  // 13税务机关核定的应税所得率（
	Ynssde        float64 `json:"ynssde"`        // 14应纳税所得额（第10×11行） \ [第10行÷（1-第11行）×第11行]
	Sl            float64 `json:"sl"`            // 15税率（25%）
	Ynsdse        float64 `json:"ynsdse"`        // 16应纳所得税额（12×13）
	JFhtjdxflqy   float64 `json:"jFhtjdxflqy"`   // 17减：符合条件的小型微利企业减免企业所得税
	JSjyjnsdse    float64 `json:"jSjyjnsdse"`    // 18减：实际已缴纳所得税额
	Bqybtsdse     float64 `json:"bqybtsdse"`     // 19本期应补（退）所得税额（14-15-16） \ 税务机关核定本期应纳所得税额
	Mzzzdfdzzjg   float64 `json:"mzzzdfdzzjg"`   // 20民族自治地方的自治机关对本民族自治地方的企业应缴纳的企业所得税中属于地方分享的部分减征或免征（
	Bqsjybtsdse   float64 `json:"bqsjybtsdse"`   // 21本期实际应补（退）所得税额
	Jccyrs        string  `json:"jccyrs"`        // 季初从业人数
	Jmcyrs        string  `json:"jmcyrs"`        // 季末从业人数
	Jczcze        string  `json:"jczcze"`        // 季初资产总额（万元）
	Jmzcze        string  `json:"jmzcze"`        // 季末资产总额（万元）
	Gjxzhjzhy     string  `json:"gjxzhjzhy"`     // 国家限制或禁止行业1-是 2否
	Xxwlqyjd      string  `json:"xxwlqyjd"`      // 小型微利企业(季度)1-是 2否
	Xxwlqynd      string  `json:"xxwlqynd"`      // 小型微利企业(年度)1-是 2否

	Qccyrs1 string `json:"qccyrs1"`
	Qccyrs2 string `json:"qccyrs2"`
	Qccyrs3 string `json:"qccyrs3"`
	Qccyrs4 string `json:"qccyrs4"`
	Qmcyrs1 string `json:"qmcyrs1"`
	Qmcyrs2 string `json:"qmcyrs2"`
	Qmcyrs3 string `json:"qmcyrs3"`
	Qmcyrs4 string `json:"qmcyrs4"`

	Qczcze1 string `json:"qczcze1"`
	Qczcze2 string `json:"qczcze2"`
	Qczcze3 string `json:"qczcze3"`
	Qczcze4 string `json:"qczcze4"`
	Qmzcze1 string `json:"qmzcze1"`
	Qmzcze2 string `json:"qmzcze2"`
	Qmzcze3 string `json:"qmzcze3"`
	Qmzcze4 string `json:"qmzcze4"`

	Yhjn       string `json:"yhjn"`
	Yhjnstatus int    `json:"yhjnstatus"`
	Yhjntext   string `json:"yhjntext"`
	Jzfd       string `json:"jzfd"`
}

// 一般纳税人增值税
type GsVat struct {
	Type           int    `json:"type"`                                 // 0 一般项目 本月数1 一般项目 本年累计 2 即征即退项目 本月数 3 即征即退项目 本年累计
	Asysljsxse     string `json:"asysljsxse" gorm:"default:'0.00'"`     // 1: （一）按适用税率计税销售额
	Yshwxse        string `json:"yshwxse" gorm:"default:'0.00'"`        // 2: 其中：应税货物销售额
	Yslwxse        string `json:"yslwxse" gorm:"default:'0.00'"`        // 3: 应税劳务销售额
	SyslNsjctzxse  string `json:"syslNsjctzxse" gorm:"default:'0.00'"`  // 4:  纳税检查调整的销售额
	Ajybfjsxse     string `json:"ajybfjsxse" gorm:"default:'0.00'"`     // 5: （二）按简易办法计税销售额
	JybfNsjctzxse  string `json:"jybfNsjctzxse" gorm:"default:'0.00'"`  // 6: 其中：纳税检查调整的销售额
	Mdtbfckxse     string `json:"mdtbfckxse" gorm:"default:'0.00'"`     // 7: （三）免、抵、退办法出口销售额
	Msxse          string `json:"msxse" gorm:"default:'0.00'"`          // 8: （四）免税销售额
	Mshwxse        string `json:"mshwxse" gorm:"default:'0.00'"`        // 9: 其中：免税货物销售额
	Mslwxse        string `json:"mslwxse" gorm:"default:'0.00'"`        // 10:   免税劳务销售额
	Xxse           string `json:"xxse" gorm:"default:'0.00'"`           // 11: 销项税额
	Jxse           string `json:"jxse" gorm:"default:'0.00'"`           // 12: 进项税额
	Sqldse         string `json:"sqldse" gorm:"default:'0.00'"`         // 13: 上期留抵税额
	Jxsezc         string `json:"jxsezc" gorm:"default:'0.00'"`         // 14: 进项税额转出
	Mdtytse        string `json:"mdtytse" gorm:"default:'0.00'"`        // 15: 免、抵、退应退税额
	SyslNsjcybjse  string `json:"syslNsjcybjse" gorm:"default:'0.00'"`  // 16: 按适用税率计算的纳税检查应补缴税额
	Ydksehj        string `json:"ydksehj" gorm:"default:'0.00'"`        // 17: 应抵扣税额合计
	Sjdkse         string `json:"sjdkse" gorm:"default:'0.00'"`         // 18: 实际抵扣税额  （如17&lt;11，则为17，否则为11）
	Ynse           string `json:"ynse" gorm:"default:'0.00'"`           // 19: 应纳税额 19=11-18
	Qmldse         string `json:"qmldse" gorm:"default:'0.00'"`         // 20: 期末留抵税额 20=17-18
	JybfYnse       string `json:"jybfYnse" gorm:"default:'0.00'"`       // 21: 简易计税办法计算的应纳税额
	JybfNsjcybjse  string `json:"jybfNsjcybjse" gorm:"default:'0.00'"`  // 22: 按简易计税办法计算的纳税检查应补缴税额
	Ynsejze        string `json:"ynsejze" gorm:"default:'0.00'"`        // 23: 应纳税额减征额
	Ynsehj         string `json:"ynsehj" gorm:"default:'0.00'"`         // 24: 应纳税额合计 24=19&#43;21-23
	Qcwjse         string `json:"qcwjse" gorm:"default:'0.00'"`         // 25 期初未缴税额（多缴为负数）
	Ssckkjzyjkstse string `json:"ssckkjzyjkstse" gorm:"default:'0.00'"` // 26: 实收出口开具专用缴款书退税额
	Bqyjse         string `json:"bqyjse" gorm:"default:'0.00'"`         // 27: 本期已缴税额 27=28&#43;29&#43;30&#43;31
	Fcyjse         string `json:"fcyjse" gorm:"default:'0.00'"`         // 28: ①分次预缴税额
	Ckkjzyjksyjse  string `json:"ckkjzyjksyjse" gorm:"default:'0.00'"`  // 29: ②出口开具专用缴款书预缴税额
	Bqjnsqynse     string `json:"bqjnsqynse" gorm:"default:'0.00'"`     // 30: ③本期缴纳上期应纳税额
	Bqjnqjse       string `json:"bqjnqjse" gorm:"default:'0.00'"`       // 31: ④本期缴纳欠缴税额
	Qmwjse         string `json:"qmwjse" gorm:"default:'0.00'"`         // 32: 期末未缴税额（多缴为负数）32=24&#43;25&#43;26-27
	QmwjseQjse     string `json:"qmwjseQjse" gorm:"default:'0.00'"`     // 33: 其中：欠缴税额（≥0）33=25&#43;26-27
	Bqybtse        string `json:"bqybtse" gorm:"default:'0.00'"`        // 34: 本期应补(退)税额  34＝24-28-29
	Jzjtsjtse      string `json:"jzjtsjtse" gorm:"default:'0.00'"`      // 35: 即征即退实际退税额
	Qcwjcbse       string `json:"qcwjcbse" gorm:"default:'0.00'"`       // 36: 期初未缴查补税额
	Bqrkcbse       string `json:"bqrkcbse" gorm:"default:'0.00'"`       // 37: 本期入库查补税额
	Qmwjcbse       string `json:"qmwjcbse" gorm:"default:'0.00'"`       // 38: 期末未缴查补税额
	Cjs            string `json:"cjs"`
	Jyf            string `json:"jyf"`
	Dfjyf          string `json:"dfjyf"`
}

// 增值税减免税申报明细表 减税
type GsVatJsxm struct {
	Type       int     `json:"type"`
	Qcye       float64 `json:"qcye"`     // 期初余额
	Bqfse      float64 `json:"bqfse"`    // 本期发生额
	Bqydjse    float64 `json:"bqydjse"`  // 本期应抵减税额 3=1&#43;2
	Bqsjdjse   float64 `json:"bqsjdjse"` // 本期实际抵减税额 4≤3
	Qmye       float64 `json:"qmye"`     // 期末余额 5=3-4
	SwsxDm     string  `json:"swsxDm"`   //
	Hmc        string  `json:"hmc"`      //
	Hmc1       string  `json:"hmc1"`     //
	Ewbhxh     float64 `json:"ewbhxh"`   //
	Hmc2       string  `json:"hmc2"`     //
	GsJmxzdmID uint    `json:"gs_jmxzdm_id"`
}

type GsVatNcp struct {
	Type   int     `json:"type"`
	Name   string  `json:"name"`
	HyName string  `json:"hyName"`
	L1     float64 `json:"l1"`
	L2     float64 `json:"l2"`
	L3     float64 `json:"l3"`
	L4     float64 `json:"l4"`
	L5     float64 `json:"l5"`
	L6     float64 `json:"l6"`
	L7     float64 `json:"l7"`
	L8     float64 `json:"l8"`
	L9     float64 `json:"l9"`
}

type GsVatNcpHzb struct {
	Trccf           float64 `json:"trccf"`
	TrccfRemark     string  `json:"trccfRemark"`
	Cbf             float64 `json:"cbf"`
	CbfRemark       string  `json:"cbfRemark"`
	Gjncpzjxs       float64 `json:"gjncpzjxs"`
	GjncpzjxsRemark string  `json:"gjncpzjxsRemark"`
	Gjncpyysc       float64 `json:"gjncpyysc"`
	GjncpyyscRemark string  `json:"gjncpyyscRemark"`
}

type GsVatAttach1 struct {
	Type              uint    `json:"type"`              // 竖列的栏次
	KjskzzszyfpXse    float64 `json:"kjskzzszyfpXse"`    // 横列 1
	KjskzzszyfpXxynse float64 `json:"kjskzzszyfpXxynse"` // 横列 2
	KjqtfpXse         float64 `json:"kjqtfpXse"`         // 3
	KjqtfpXxynse      float64 `json:"kjqtfpXxynse"`      // 4
	WkjfpXse          float64 `json:"wkjfpXse"`          // 5
	WkjfpXxynse       float64 `json:"wkjfpXxynse"`       // 6
	Nsjctzdxse        float64 `json:"nsjctzdxse"`        // 7
	NsjctzXxynse      float64 `json:"nsjctzXxynse"`      // 8
	Xse               float64 `json:"xse"`               // 9
	HjXxynse          float64 `json:"hjXxynse"`          // 10
	Jshj              float64 `json:"jshj"`              // 11
	Ysfwkcxmbqsjkcje  float64 `json:"ysfwkcxmbqsjkcje"`  // 12
	KchHsmsxse        float64 `json:"kchHsmsxse"`        // 13
	KchXxynse         float64 `json:"kchXxynse"`         // 14
}

type GsVatAttach2 struct {
	Type uint    `json:"type"` // 竖列的栏次
	Fs   float64 `json:"fs"`   // 份数
	Je   float64 `json:"je"`   // 金额
	Se   float64 `json:"se"`   // 税额
}

type GsVatAttach3 struct {
	Type     int     `json:"type"`     // 竖列的栏次
	Msxse    float64 `json:"msxse"`    //
	Qcye     float64 `json:"qcye"`     //
	Bqfse    float64 `json:"bqfse"`    //
	Bqykcje  float64 `json:"bqykcje"`  //
	Bqsjkcje float64 `json:"bqsjkcje"` //
	Qmye     float64 `json:"qmye"`     //
	Remark   string  `json:"remark"`   //
}

type GsVatAttach4 struct {
	Type         float64 `json:"type"`         // 竖列的栏次
	Qcye         float64 `json:"qcye"`         // 期初余额 1
	Bqfse        float64 `json:"bqfse"`        // 本期发生额 Se
	Bqydjse      float64 `json:"bqydjse"`      // 本期应抵减税额	3=1&#43;2
	Bqsjdjse     float64 `json:"bqsjdjse"`     // 本期实际抵减税额 4≤3
	Qmye         float64 `json:"qmye"`         // 期末余额 5=3-4
	Bqzce        float64 `json:"bqzce"`        //二、加计抵减情况 本期调减额
	Bqsjjjdkjxse float64 `json:"bqsjjjdkjxse"` //本期实际抵减额
	Bqkjjdkjxse  float64 `json:"bqkjjdkjxse"`  //本期可抵减额
}

type GsVatBc struct {
	Q0002 float64 `json:"q0002"` //
	Q0021 float64 `json:"q0021"` //
	Q0022 float64 `json:"q0022"` //
	Q0003 float64 `json:"q0003"` //
	Q0004 float64 `json:"q0004"` //
	Q0038 float64 `json:"q0038"` //
	Q0606 float64 `json:"q0606"` //
	Q0607 float64 `json:"q0607"` //
	Q0608 float64 `json:"q0608"` //
	Q0054 float64 `json:"q0054"` //
	Q0052 float64 `json:"q0052"` //
	Q0053 float64 `json:"q0053"` //
}

// 增值税纳税申报表（适用于增值税小规模纳税人）附列资料
type GsSmallVat struct {
	Type                  float64 `json:"type"`                  // 0 本期数-货物及劳务 1 本期数-服务、不动产和无形资产 2本年累计-货物及劳务 3本年累计-服务、不动产和无形资产
	Yzzzsbhsxse           string  `json:"yzzzsbhsxse"`           // （一） 应征增值税不含税销售额（3%征收率）1
	Swjgdkdzzszyfpbhsxse  string  `json:"swjgdkdzzszyfpbhsxse"`  //  税务机关代开的增值税专用发票不含税销售额  2
	Skqjkjdptfpbhsxse     string  `json:"skqjkjdptfpbhsxse"`     // 税控器具开具的普通发票不含税销售额  3
	Xsczbdcbhsxse         string  `json:"xsczbdcbhsxse"`         // （二）应征增值税不含税销售额（5%征收率）4
	Swjgdkdzzszyfpbhsxse1 string  `json:"swjgdkdzzszyfpbhsxse1"` // 税务机关代开的增值税专用发票不含税销售额  5
	Skqjkjdptfpbhsxse2    string  `json:"skqjkjdptfpbhsxse2"`    // 税控器具开具的普通发票不含税销售额  6
	Xssygdysgdzcbhsxse    string  `json:"xssygdysgdzcbhsxse"`    // （三）销售使用过的固定资产不含税销售额 7（7&gt;=8）
	Skqjkjdptfpbhsxse1    string  `json:"skqjkjdptfpbhsxse1"`    // 其中：税控器具开具的普通发票不含税销售额 8
	Msxse                 string  `json:"msxse"`                 // （四）免税销售额  9=10&#43;11&#43;12
	Xwqymsxse             string  `json:"xwqymsxse"`             // 其中：小微企业免税销售额  10
	Wdqzdxse              string  `json:"wdqzdxse"`              // 未达起征点销售额  11
	Qtmsxse               string  `json:"qtmsxse"`               // 其他免税销售额  12
	Ckmsxse               string  `json:"ckmsxse"`               // （五）出口免税销售额  13(13&gt;=14)
	Skqjkjdptfpxse1       string  `json:"skqjkjdptfpxse1"`       // 其中：税控器具开具的普通发票销售额  14
	Hdxse                 string  `json:"hdxse"`                 // 核定销售额  15
	Bqynse                string  `json:"bqynse"`                // 本期应纳税额  16
	Hdynse                string  `json:"hdynse"`                // 核定应税额  17
	Bqynsejze             string  `json:"bqynsejze"`             // 本期应纳税额减征额  18
	Bqmse                 string  `json:"bqmse"`                 // 本期免税额  19
	Xwqymse               string  `json:"xwqymse"`               // 其中：小微企业免税额  20
	Wdqzdmse              string  `json:"wdqzdmse"`              // 未达起征点免税额  21
	Ynsehj                string  `json:"ynsehj"`                // 应纳税额合计  22=16-18或17-18
	Bqyjse1               string  `json:"bqyjse1"`               // 本期预缴税额  23
	Bqybtse               string  `json:"bqybtse"`               // 本期应补（退）税额 24=22-23
	Cjs                   string  `json:"cjs"`
	Jyf                   string  `json:"jyf"`
	Dfjyf                 string  `json:"dfjyf"`
}

type GsSmallVatAttached struct {
	Qcye          string `json:"qcye"`          // 期初余额 1
	Bqfse         string `json:"bqfse"`         // 本期发生额 2
	Bqkce         string `json:"bqkce"`         // 本期扣除额 3（3≤1＋2之和，且3≤5）
	Qmye          string `json:"qmye"`          // 期末余额 4＝1＋2－3
	Ysfwxsqbhssr  string `json:"ysfwxsqbhssr"`  // 全部含税收入 5
	Bqkce_        string `json:"bqkce_"`        // 本期扣除额 6=3
	Ysfwxshsxse   string `json:"ysfwxshsxse"`   // 含税销售额 7=5-6
	Ysfwxsbhsxse  string `json:"ysfwxsbhsxse"`  // 不含税销售额 8＝7÷1.03
	Qcye5         string `json:"qcye5"`         // 期初余额 9
	Bqfse5        string `json:"bqfse5"`        // 本期发生额 10
	Bqkce5        string `json:"bqkce5"`        // 本期扣除额 11（11≤9＋10之和，且11≤13）
	Qmye5         string `json:"qmye5"`         // 期末余额 12＝9＋10－11
	Ysfwxsqbhssr5 string `json:"ysfwxsqbhssr5"` // 全部含税收入 13
	Bqkce5_       string `json:"bqkce5_"`       // 本期扣除额 14=11
	Ysfwxshsxse5  string `json:"ysfwxshsxse5"`  // 含税销售额 15=13-14
	Ysfwxsbhsxse5 string `json:"ysfwxsbhsxse5"` // 不含税销售额 16＝15÷1.05
}

type GsSmallVatReduce struct {
	Qcyehj        string `json:"qcyehj"`        // 一、减税项目 期初余额 1
	Bqfsehj       string `json:"bqfsehj"`       // 本期发生额 2
	Bqydjsehj     string `json:"bqydjsehj"`     // 本期应抵减税额 3=1&#43;2
	Bqsjdjsehj    string `json:"bqsjdjsehj"`    // 本期实际抵减税额 4≤3
	Qmyehj        string `json:"qmyehj"`        // 期末余额 5=3-4
	Mzzzsxmxsehj  string `json:"mzzzsxmxsehj"`  // 二、免税项目 免征增值税项目销售额 1
	Bqsjkcjehj    string `json:"bqsjkcjehj"`    // 免税销售额扣除项目本期实际扣除金额 2
	Kchmsxsehj    string `json:"kchmsxsehj"`    // 扣除后免税销售额 3=1-2
	Msxsedyjxsehj string `json:"msxsedyjxsehj"` // 免税销售额对应的进项税额 4
	Msehj         string `json:"msehj"`         // 免税额 5

	Jmxzdm string `json:"jmxzdm"`
	Hmc    string `json:"hmc"`

	Ckmzzzsxmxse string `json:"ckmzzzsxmxse"` // 出口免税-免征增值税项目销售额 1
	Kjmzzzsxmxse string `json:"kjmzzzsxmxse"` // 其中:跨境服务-免征增值税项目销售额 1

	Qcyehj2     string `json:"qcyehj_2"`     // 一、减税项目 期初余额 1
	Bqfsehj2    string `json:"bqfsehj_2"`    // 本期发生额 2
	Bqydjsehj2  string `json:"bqydjsehj_2"`  // 本期应抵减税额 3=1&#43;2
	Bqsjdjsehj2 string `json:"bqsjdjsehj_2"` // 本期实际抵减税额 4≤3
	Qmyehj2     string `json:"qmyehj_2"`     // 期末余额 5=3-4
}

// 资产负债表（适用执行小企业会计准则的企业）
type KjZcfz struct {
	Type   float64 `json:"type"`   // 对应资产负债表行次字段 不标准
	Zcxmmc string  `json:"zcxmmc"` // 流动资产
	QmyeZc float64 `json:"qmyeZc"` // 期末余额
	NcyeZc float64 `json:"ncyeZc"` // 年初余额
	Qyxmmc string  `json:"qyxmmc"` // 流动负债
	QmyeQy float64 `json:"qmyeQy"` // 期末余额
	NcyeQy float64 `json:"ncyeQy"` // 年初余额
}

// 利润表
type KjLrb struct {
	Project     string  `json:"project"`     // 项目
	Type        float64 `json:"type"`        // 对应利润表行次
	YearTotal   float64 `json:"yearTotal"`   // 核定比例
	PeriodTotal float64 `json:"periodTotal"` // 适用税率
}

type KjXjllb struct {
	Project     string  `json:"project"`     // 项目
	Type        float64 `json:"type"`        //
	YearTotal   float64 `json:"yearTotal"`   //
	PeriodTotal float64 `json:"periodTotal"` //
}

type SbRespone struct {
	Status         int8   `json:"status"`         // 2 成功 3失败
	ErrLog         string `json:"errLog"`         // rod 失败原因
	BusinessStatus int8   `json:"businessStatus"` //2 成功 3 失败
	BusinessLog    string `json:"businessLog"`    //业务失败原因
	BusinessImg    string `json:"businessImg"`    //申报成功或者失败截图
}

// 业务活动表
type KjYwhdb struct {
	KjMainID        uint    `json:"kjMainId"`      //
	Project         string  `json:"project"`       // 项目
	Type            int     `json:"type"`          // 对应利润表行次
	YearFxdxTotal   float64 `json:"yearFxdxTotal"` // 核定比例
	YearXdxTotal    float64 `json:"yearXdxTotal"`
	PeriodFxdxTotal float64 `json:"periodFxdxTotal"`
	PeriodXdxTotal  float64 `json:"periodXdxTotal"`
}

// 专业合作社盈余分配表
type KjYyfpb struct {
	Type         int     `json:"type"`    //
	Project      string  `json:"project"` //
	Amount       float64 `json:"amount"`  //
	AmountPeriod float64 `json:"amountPeriod"`
}

// 成员权益变动表
type KJCyqybdb struct {
	KjMainID uint    `json:"kjMainId"` //
	Project  string  `json:"project"`  // 项目
	Type     int     `json:"type"`     //
	GJ       float64 `json:"gj"`       //股金
	Zxjj     float64 `json:"zxjj"`     //专项基金
	Zbgj     float64 `json:"zbgj"`     //资本公积
	Yygj     float64 `json:"yygj"`     //盈余公积
	Wfpyy    float64 `json:"wfpyy"`    //未分配盈余
	Total    float64 `json:"total"`    //合计
}

// 申报清册信息||当月应申报信息
type Sbqc struct {
	ZsxmMc string   `json:"zsxmMc"` // 征收项目名称
	ZspmMc string   `json:"zspmMc"` // 征收品目名称
	SkssqQ string   `json:"skssqQ"` // 税款所属期起
	SkssqZ string   `json:"skssqZ"` // 税款所属期止
	Sbrq   string   `json:"sbrq"`   // 申报日期
	Sbqx   string   `json:"sbqx"`   // 申报期限
	Sbzt   SbStatus `json:"sbzt"`   // 申报状态
	Jkzt   JkStatus `json:"jkzt"`   // 缴款状态
	Pdf    string   `json:"pdf"`    // 采集的pdf路径
	Data   any      `json:"data"`   // 集成的申报数据
	Error  string   `json:"error"`  // 集成的申报数据的错误信息
}

type SbStatus int //业务状态

const (
	_           SbStatus = iota // 未申报
	SbSuccess                   // 已申报-已申报(已导入)
	WaitReceipt                 // 已申报未导入-等待回执 等等
)

type JkStatus int //业务状态

const (
	_                JkStatus = iota // 无需交款-税局未显示交款状态
	SbSuccessNeedPay                 // 未交款
	SbSuccessPaid                    // 已交款
)

// 完税证明
type Wszm struct {
	Pzh    string     `json:"pzh"`
	Skssqq string     `json:"skssqq"`
	Skssqz string     `json:"skssqz"`
	Rkrq   string     `json:"rkrq"`
	Amount string     `json:"amount"`
	Item   []WszmItem `json:"item"`
	Pdf    string     `json:"pdf"`
}

type WszmItem struct {
	Zsxm   string `json:"zsxm"`
	Zspm   string `json:"zspm"`
	Skssqq string `json:"skssqq"`
	Skssqz string `json:"skssqz"`
	Rkrq   string `json:"rkrq"`
	Amount string `json:"amount"`
}

type Yhs struct {
	Sz     string `json:"sz"`
	Sm     string `json:"sm"`
	Skssqq string `json:"skssqq"`
	Skssqz string `json:"skssqz"`
	Jsyj   string `json:"jsyj"`
	Sl     string `json:"sl"`
	Ynse   string `json:"ynse"`
	Jmse   string `json:"jmse"`
	Yjse   string `json:"yjse"`
	Ybyse  string `json:"ybyse"`
	Lslf   bool   `json:"lslf"`
}

type YhsFb struct {
	Bh     string `json:"bh"`
	Skssqq string `json:"skssqq"`
	Skssqz string `json:"skssqz"`
	Jmxzdm string `json:"jmxzdm"`
	Jmse   string `json:"jmse"`
}

type Whsy struct {
	Xm          string `json:"xm"`
	PeriodTotal string `json:"periodTotal"`
	YearTotal   string `json:"yearTotal"`
}
